-- #########################################################
-- #########################################################
-- ConfigEnv.sql
-- #########################################################
-- #########################################################

SPOOL spool.txt
WHENEVER SQLERROR EXIT FAILURE ROLLBACK
WHENEVER OSERROR EXIT FAILURE ROLLBACK

-- #########################################################
-- #########################################################
-- VersionCheck.sql
-- #########################################################
-- #########################################################

declare
  Major$ NUMBER(10);
  Minor$ NUMBER(10);
begin
  select max(Major) into Major$ from DatabaseVersion;
  select max(Minor) into Minor$ from DatabaseVersion where Major = Major$;
  if (Major$ <> 1100) or (Minor$ <> 00) then
    raise_application_error(-20000, '  [' || TO_CHAR(Major$) || '.' || TO_CHAR(Minor$, 'FM00') || ']    [1100.00]');
  end if;
end;
/

-- #########################################################
-- #########################################################
-- TenderObjects_BU_500_Active.sql
-- #########################################################
-- #########################################################

ALTER TRIGGER TR_TENDEROBJECTS_BU_500 ENABLE
/
commit work
/


-- #########################################################
-- #########################################################
-- alter_BuhAccPlan_2016.sql
-- #########################################################
-- #########################################################

/*  EcCls       ,   */
ALTER TABLE BUHACCPLAN DROP CONSTRAINT UNQ_BUHACCPLAN_ACC_EC DROP INDEX
/
ALTER TRIGGER TR_BUHACCPLAN_BU_500 DISABLE
/
ALTER TABLE BuhAccPlan ADD (
  EcClsTemp NUMBER(10),
    CHECK((EcClsTemp<=2147483647)AND(EcClsTemp>-2147483648))
)
/
commit work 
/
update BuhAccPlan set
  EcClsTemp = EcCls
/
commit work 
/
ALTER TABLE BuhAccPlan DROP (EcCls)
/
commit work 
/
ALTER TABLE BuhAccPlan ADD (
  EcCls VARCHAR2(20)
)
/
commit work 
/
update BuhAccPlan set
  EcCls = '00' || cast(EcClsTemp as VARCHAR2(255))
where
  (EcClsTemp <= 9)
/
update BuhAccPlan set
  EcCls = '0' || cast(EcClsTemp as VARCHAR2(255))
where
  (EcClsTemp >= 10) and (EcClsTemp <= 99)
/
update BuhAccPlan set
  EcCls = cast(EcClsTemp as VARCHAR2(255))
where
  (EcClsTemp >= 100)
/
update BuhAccPlan set
  ClsType = 0
/
commit work 
/
ALTER TABLE BuhAccPlan DROP (EcClsTemp)
/
ALTER TRIGGER TR_BUHACCPLAN_BU_500 ENABLE
/
commit work 
/
ALTER TABLE BuhAccPlan MODIFY(EcCls NOT NULL)
/

-- #########################################################
-- #########################################################
-- Alter_RemoteClient_11.10.sql
-- #########################################################
-- #########################################################

/*    RemoteClient.OwnCopies
*/
ALTER TABLE RemoteClient ADD (
  OwnCopies NUMBER(10)/*    ( ) */,
    CHECK((OwnCopies<=2147483647)AND(OwnCopies>-2147483648))
)
/
commit work 
/

-- #########################################################
-- #########################################################
-- ProtocolReason91_oracle.sql
-- #########################################################
-- #########################################################


/* ***************************************
  ''
****************************************/
/*      */
alter trigger TR_ProtocolReason_BI disable
/

alter trigger TR_ProtocolReason_BU disable
/

create or replace procedure AddProtocolReason(ID$ Number, Name$ VarChar2)
as
  cnt$ Number(10);
begin
    select count(*) into cnt$
    from ProtocolReason
    where ID = ID$;

    if cnt$ = 0 then
      insert into ProtocolReason(ID, Name, CreateDate, UpdateDate) values(ID$, Name$, SYSDATE, SYSDATE);
    else
      update ProtocolReason set
        Name = Name$
      where 
        ID = ID$;
    end if;
end;
/

call AddProtocolReason(91, '. 93 . 1 . 46 44-  05.04.2013.')
/

alter trigger TR_ProtocolReason_BI enable
/

alter trigger TR_ProtocolReason_BU enable
/

commit work
/



-- #########################################################
-- #########################################################
-- Alter_Banks_1110.sql
-- #########################################################
-- #########################################################

/*       */
-- CREATE TRIGGER tr_Banks_bu
CREATE OR REPLACE TRIGGER TR_BANKS_IU
  INSTEAD OF UPDATE
  ON BANKS
  FOR EACH ROW
DECLARE
  new$ID BANKS.ID%TYPE := :NEW.ID;
  new$MFO BANKS.MFO%TYPE := :NEW.MFO;
  new$COR BANKS.COR%TYPE := :NEW.COR;
  new$CLOSED BANKS.CLOSED%TYPE := :NEW.CLOSED;
  new$UER BANKS.UER%TYPE := :NEW.UER;
  new$UERREAL BANKS.UERREAL%TYPE := :NEW.UERREAL;
  new$PZN BANKS.PZN%TYPE := :NEW.PZN;
  new$DATECLOSE BANKS.DATECLOSE%TYPE := :NEW.DATECLOSE;
  new$UPDATEDATE BANKS.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$CREATEDATE BANKS.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$CREATERUSER BANKS.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER BANKS.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (tr_banks_bu)
-- Version 11.10.00.1
-- - - - - - - - - - - - -

  /*  ,       */
  if ((:old.mfo is null and new$mfo is not null)
  or (:old.mfo is not null and new$mfo is null)
  or (:old.cor is null and new$cor is not null)
  or (:old.cor is not null and new$cor is null)
  or (new$mfo <> :old.mfo)
  or (new$cor <> :old.cor))
  then
    CHECK_UNIQUE_BANK(new$MFO, new$COR);
  END IF;
    
  /*    */
  if (new$DateClose is not null) then
    new$Closed := 1;
    /*     */
    if (:old.DateClose is null) then
      update Org_Accounts set
      CloseCode = CloseCode + 1000,
      DateClose = new$DateClose
      where Bank_Ref = new$ID;
      
    END IF;
  END IF;
  /*    */
  if (new$DateClose is null) then
    new$Closed := null;
    /*      */
    if (:old.DateClose is not null) then
      update Org_Accounts set CloseCode = CloseCode - 1000 where Bank_Ref = new$ID;
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_BANKS SET
    ID = new$ID,
    MFO = new$MFO,
    COR = new$COR,
    CLOSED = new$CLOSED,
    UER = new$UER,
    UERREAL = new$UERREAL,
    PZN = new$PZN,
    DATECLOSE = new$DATECLOSE,
    UPDATEDATE = new$UPDATEDATE,
    CREATEDATE = new$CREATEDATE,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER
  WHERE ID = :old.ID;

  if SQL%ROWCOUNT <> 1 then
    RaiseException('EX_RECORDCHANGED');
  end if;

-- - - - - - - - - - - - -
-- AU_0 (TR_BANKS_AU)
-- Create 27.07.2007
-- - - - - - - - - - - - -

  /*    */
  if ((new$DateClose is not null) and (:old.DateClose is null)) then
   /*    */
   update Organizations set
     DateClose = new$DateClose
   where (ID = new$ID) and (DateClose is null);
  end if;

  /*    */
  if ((new$DateClose is null) and (:old.DateClose is not null)) then
   /*    */
    update Organizations set
      DateClose = null
    where (ID = new$ID) and (DateClose is not null);
  end if;

-- - - - - - - - - - - - -
-- AU_500 (TR_BANKS_AU_500)
-- Create 28.04.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (20, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=20) and (RecordId=new$ID);
  end if;

END;
/
commit work
/

-- #########################################################
-- #########################################################
-- Fix_KD_Triggers.sql
-- #########################################################
-- #########################################################

/*     */
-- ALTER TRIGGER tr_kd_au_100
CREATE OR REPLACE TRIGGER TR_KD_IU
  INSTEAD OF UPDATE
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  CNT$1 NUMBER(10);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sAnalyticalGroupKD$ VARCHAR2(3);
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_KD_BU_0)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*     */
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupKD is null) then 
    new$AnalyticalGroupKD := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR <> 0) then
    select max(kd_level) into sKDLevel$ from KD where ((AnalyticalGroupKD = new$AnalyticalGroupKD) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
    and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
  END IF;
  if (sKDLevel$ is not null) then
    new$kd_Level := sKDLevel$;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*       */    
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode2$ := tmp_Double$;
      
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '0000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '00' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '0' || DescrCode1$;
                
          else
            sDescrCode1$ := DescrCode1$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '0000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '00' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '0' || DescrCode2$;
                
          else
            sDescrCode2$ := DescrCode2$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupKD$ from AnalyticalGroupKD where (ID = new$AnalyticalGroupKD) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupKD$;
  END IF;
  /*      */    
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sAnalyticalGroupKD$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_KD SET
    ID = new$ID,
    REPCODE = new$REPCODE,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    KDVALUE = new$KDVALUE,
    REMOTEFLAG = new$REMOTEFLAG,
    UNIONFLAG = new$UNIONFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    KD_LEVEL = new$KD_LEVEL,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPKD = new$ANALYTICALGROUPKD
  WHERE id = :old.id;

-- - - - - - - - - - - - -
-- AU_100 (TR_KD_AU_100)
-- Version 11.10.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    where ((kd1.kvsr = 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and
    (kd1.BudgetRef = new$BudgetRef) and
    ((kd1.ExtID = new$ExtID)or((kd1.ExtID is null)and(new$ExtID is null)))
    ) AND (ROWNUM = 1)                     ;
    /*    0,        =0 */
    if (not (CNT$1<> 0))
    then
      insert into KD (KVSR, DescriptionCode, ProgramCode, AnalyticalGroupKD, Name, ShortName, RemoteFlag, kd_level, budgetref, extid)
      values (0, new$DescriptionCode, new$ProgramCode, new$AnalyticalGroupKD, new$Name, new$ShortName, new$RemoteFlag, new$kd_level, new$budgetref, new$extid);
        
    END IF;
  else
    /*   = 0,         ,     */
    update kd kd1 set
    name = new$name,
    ShortName = new$ShortName, 
    kd_level = new$kd_level
    where
    (kd1.kvsr <> 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and
    (kd1.BudgetRef = new$BudgetRef) and
    (kd1.ExtID = new$ExtID);
    /*        */
    if (new$deletedate is not null) then
      update kd kd1 set
      deletedate = new$deletedate
      where
      (kd1.kvsr <> 0) and
      ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
      (kd1.programcode = new$programcode) and
      (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and
      (kd1.DeleteDate is null) and
      (kd1.BudgetRef = new$BudgetRef) and
      (kd1.ExtID = new$ExtID);
        
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_KD_AU_500)
-- Create 28.04.2005
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (80, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=80) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER tr_kd_ai_100
CREATE OR REPLACE TRIGGER TR_KD_II
  INSTEAD OF INSERT
  ON KD
  FOR EACH ROW
DECLARE
  new$ID KD.ID%TYPE := :NEW.ID;
  new$REPCODE KD.REPCODE%TYPE := :NEW.REPCODE;
  new$CREATEDATE KD.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE KD.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$KVSR KD.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE KD.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE KD.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE KD.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE KD.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR KD.KESR%TYPE := :NEW.KESR;
  new$KDVALUE KD.KDVALUE%TYPE := :NEW.KDVALUE;
  new$REMOTEFLAG KD.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$UNIONFLAG KD.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$BUDGETREF KD.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE KD.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME KD.NAME%TYPE := :NEW.NAME;
  new$KD_LEVEL KD.KD_LEVEL%TYPE := :NEW.KD_LEVEL;
  new$STARTDATE KD.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME KD.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CREATERUSER KD.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER KD.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$EXTID KD.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER KD.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE KD.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID KD.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION KD.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE KD.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPKD KD.ANALYTICALGROUPKD%TYPE := :NEW.ANALYTICALGROUPKD;
--
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(5);
  sDescrCode2$ VARCHAR2(5);
  sProgCode$ VARCHAR2(4);
  sAnalyticalGroupKD$ VARCHAR2(3);
  CNT$1 NUMBER(10);
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sKDLevel$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_KD_BI_0)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupKD is null) then 
    new$AnalyticalGroupKD := 0;
  END IF;
  if (new$ProgramCode is null) then 
    new$ProgramCode := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  if (new$KVSR <> 0) then
    select max(kd_level) into sKDLevel$ from KD where ((AnalyticalGroupKD = new$AnalyticalGroupKD) and (ProgramCode=new$ProgramCode)and (BudgetRef=new$BudgetRef)
    and (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0))  ;
  END IF;
  if (sKDLevel$ is not null) then
    new$kd_Level := sKDLevel$;
  END IF;
  /*          */
    
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100;
  new$MainDescriptionCode := tmp_Double$;
  if (new$MainDescriptionCode > tmp_Double$) then 
    new$MainDescriptionCode := new$MainDescriptionCode - 1;
  END IF;
  tmp_Double$ := new$MainDescriptionCode;
  tmp_Double$ := tmp_Double$ * 100;
  new$ItemCode := tmp$ - tmp_Double$; 
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-   */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*       */    
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 100000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 100000;
  DescrCode2$ := tmp_Double$;
      
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '00000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '0000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '00' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '0' || DescrCode1$;
                
          else
            sDescrCode1$ := DescrCode1$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '00000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '0000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '00' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '0' || DescrCode2$;
                
          else
            sDescrCode2$ := DescrCode2$;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
      
  /*      */
  if (new$programcode = 0) then
    sProgCode$ := '0000';
        
  else
    if (new$programcode < 10) then
      sProgCode$ := '000' || new$programcode;
          
    else
      if (new$programcode < 100) then
        sProgCode$ := '00' || new$programcode;
            
      else
        if (new$programcode < 1000) then
          sProgCode$ := '0' || new$programcode;
              
        else
          sProgCode$ := new$programcode;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupKD$ from AnalyticalGroupKD where (ID = new$AnalyticalGroupKD) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupKD$;
  END IF;
  /*      */    
      
  new$kdvalue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sProgCode$ || sAnalyticalGroupKD$;
      
  if ((new$ID = 0) and (new$kdvalue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroKD');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_KD_BI_500)
-- Version 7.02.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_KD (
    ID,
    REPCODE,
    CREATEDATE,
    UPDATEDATE,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    KDVALUE,
    REMOTEFLAG,
    UNIONFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    KD_LEVEL,
    STARTDATE,
    SHORTNAME,
    CREATERUSER,
    UPDATERUSER,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    ANALYTICALGROUPKD
  ) VALUES (
    new$ID,
    new$REPCODE,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$KVSR,
    new$DESCRIPTIONCODE,
    new$MAINDESCRIPTIONCODE,
    new$ITEMCODE,
    new$PROGRAMCODE,
    new$KESR,
    new$KDVALUE,
    new$REMOTEFLAG,
    new$UNIONFLAG,
    new$BUDGETREF,
    new$DELETEDATE,
    new$NAME,
    new$KD_LEVEL,
    new$STARTDATE,
    new$SHORTNAME,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$ANALYTICALGROUPKD);

-- - - - - - - - - - - - -
-- AI_100 (TR_KD_AI_100)
-- Version 11.10.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from kd kd1
    where ((kd1.kvsr = 0) and
    ((kd1.descriptioncode-new$descriptioncode>-1) and (kd1.descriptioncode-new$descriptioncode<1)) and
    (kd1.programcode = new$programcode) and
    (kd1.AnalyticalGroupKD = new$AnalyticalGroupKD) and (kd1.BudgetRef = new$BudgetRef)
    and ((kd1.ExtID = new$ExtID)or((new$ExtID is null)and(new$ExtID is null)))
    ) AND (ROWNUM = 1)                   ;
    if (not (CNT$1<> 0))
    then  
      insert into KD (KVSR, DescriptionCode, ProgramCode, AnalyticalGroupKD, Name, ShortName, RemoteFlag, kd_level, budgetref, extid)
      values (0, new$DescriptionCode, new$ProgramCode, new$AnalyticalGroupKD, new$Name, new$ShortName, new$RemoteFlag, new$kd_level, new$budgetref, new$extid);
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_KD_AI_500)
-- Last update 14.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 80)  and (RecordID = new$ID);

END;
/
-- ALTER TRIGGER tr_innerfinsource_au_100
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_IU
  INSTEAD OF UPDATE
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  CNT$1 NUMBER(10);
  sAnalyticalGroupIFS$ VARCHAR2(3);
  DescrCode1$ NUMBER(10);
  DescrCode2$ NUMBER(10);
  KVSRCode1$ NUMBER(10);
  sIFSLevel$ NUMBER(10);
  sDirection$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BU_0 (TR_INNERFINSOURCE_BU_0)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupIFS is null) then 
    new$AnalyticalGroupIFS := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*     */
  if (new$KVSR <> 0) then
    BEGIN
      select IFS_Level, Direction 
      into sIFSLevel$, sDirection$     from innerfinsource 
      where ((AnalyticalGroupIFS = new$AnalyticalGroupIFS) and (BudgetRef=new$BudgetRef) and 
      (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) 
      ;
    EXCEPTION
      WHEN NO_DATA_FOUND THEN NULL;
    END;
  END IF;
  if (sIFSLevel$ is not null) then
    new$IFS_Level := sIFSLevel$;
  END IF;
  if (sDirection$ is not null) then
    new$Direction := sDirection$;
  END IF;
  /*         
            =3,5,8 */
  if (new$Direction is null) then
    if ((new$AnalyticalGroupIFS between 300 and 399) or 
    (new$AnalyticalGroupIFS between 500 and 599) or 
    (new$AnalyticalGroupIFS between 800 and 899)) then
      new$Direction := -1;
          
    else
      new$Direction := 1;
      
    END IF;
  END IF;
  BEGIN

    /*      */ 
    select Code into KVSRCode1$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-    */
  /*      */
  if (KVSRCode1$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode1$ < 10) then
      sKVSR$ := '00' || KVSRCode1$;
          
    else
      if (KVSRCode1$ < 100) then
        sKVSR$ := '0' || KVSRCode1$;
            
      else
        sKVSR$ := KVSRCode1$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode1$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode1$  > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode1$; /*    */
  /*       */    
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode2$ := tmp_Double$;
  tmp_Double$ := DescrCode2$ / 10000;
  DescrCode1$ := tmp_Double$;
  /*      */
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  new$ItemCode := DescrCode1$; /* */
  tmp_Double$ := DescrCode2$ - DescrCode1$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode1$ := tmp_Double$;
  if (DescrCode1$ > tmp_Double$) then 
    DescrCode1$ := DescrCode1$ - 1;
  END IF;
  tmp_Double$ := DescrCode1$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode2$ := tmp_Double$;
  if (DescrCode1$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode1$ < 10) then
      sDescrCode1$ := '000000' || DescrCode1$;
          
    else
      if (DescrCode1$ < 100) then
        sDescrCode1$ := '00000' || DescrCode1$;
            
      else
        if (DescrCode1$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode1$;
              
        else
          if (DescrCode1$ < 10000) then
            sDescrCode1$ := '000' || DescrCode1$;
                
          else
            if (DescrCode1$ < 100000) then
              sDescrCode1$ := '00' || DescrCode1$;
                  
            else
              if (DescrCode1$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode1$;
                    
              else
                sDescrCode1$ := DescrCode1$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode2$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode2$ < 10) then
      sDescrCode2$ := '000000' || DescrCode2$;
          
    else
      if (DescrCode2$ < 100) then
        sDescrCode2$ := '00000' || DescrCode2$;
            
      else
        if (DescrCode2$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode2$;
              
        else
          if (DescrCode2$ < 10000) then
            sDescrCode2$ := '000' || DescrCode2$;
                
          else
            if (DescrCode2$ < 100000) then
              sDescrCode2$ := '00' || DescrCode2$;
                  
            else
              if (DescrCode2$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode2$;
                    
              else
                sDescrCode2$ := DescrCode2$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupIFS$ from AnalyticalGroupIFS where (ID = new$AnalyticalGroupIFS) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupIFS$;
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sAnalyticalGroupIFS$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- UPDATE
-- - - - - - - - - - - - -
  UPDATE TB_INNERFINSOURCE SET
    ID = new$ID,
    CREATEDATE = new$CREATEDATE,
    UPDATEDATE = new$UPDATEDATE,
    DIRECTION = new$DIRECTION,
    KVSR = new$KVSR,
    DESCRIPTIONCODE = new$DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE = new$MAINDESCRIPTIONCODE,
    ITEMCODE = new$ITEMCODE,
    PROGRAMCODE = new$PROGRAMCODE,
    KESR = new$KESR,
    FINSOURCEVALUE = new$FINSOURCEVALUE,
    UNIONFLAG = new$UNIONFLAG,
    REMOTEFLAG = new$REMOTEFLAG,
    BUDGETREF = new$BUDGETREF,
    DELETEDATE = new$DELETEDATE,
    NAME = new$NAME,
    STARTDATE = new$STARTDATE,
    SHORTNAME = new$SHORTNAME,
    CLSASPECT = new$CLSASPECT,
    CREATERUSER = new$CREATERUSER,
    UPDATERUSER = new$UPDATERUSER,
    IFS_LEVEL = new$IFS_LEVEL,
    EXTID = new$EXTID,
    EXTOWNER = new$EXTOWNER,
    EXTSYNCDATE = new$EXTSYNCDATE,
    EXTROOTID = new$EXTROOTID,
    EXTVERSION = new$EXTVERSION,
    EXTVERSIONDATE = new$EXTVERSIONDATE,
    ANALYTICALGROUPIFS = new$ANALYTICALGROUPIFS
  WHERE ID = :OLD.ID;

-- - - - - - - - - - - - -
-- AU_100 (TR_INNERFINSOURCE_AU_100)
-- Version 11.10.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    where ((ifs1.kvsr = 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
    (ifs1.BudgetRef = new$BudgetRef) and
    ((ifs1.ExtID = new$ExtID)or((ifs1.ExtID is null)and(new$ExtID is null)))
    ) AND (ROWNUM = 1)
    ;
    if (not (CNT$1<> 0))
    then  
      insert into InnerFinSource (KVSR, DescriptionCode, AnalyticalGroupIFS, Name, ShortName, CLSAspect, RemoteFlag, IFS_Level, BudgetRef, ExtID)
      values (0, new$DescriptionCode, new$AnalyticalGroupIFS, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$IFS_Level, new$BudgetRef, new$ExtID);
      
    END IF;
  else
    /*   = 0,         ,     */
    update InnerFinSource ifs1 set
    name = new$name,
    ShortName = new$ShortName,
    ifs_level = new$ifs_level,
    Direction = new$Direction
    where
    (ifs1.kvsr <> 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS);
    /*        */
    if (new$deletedate is not null) then
      update InnerFinSource ifs1 set
      deletedate = new$deletedate
      where
      (ifs1.kvsr <> 0) and
      ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
      (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
      (ifs1.DeleteDate is null);
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AU_500 (TR_INNERFINSOURCE_AU_500)
-- Create 28.04.2005
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  if (new$ID<>:old.ID) then
    insert into DelRecIndexes(TableID, RecordId, DeleteDate) values (145, :old.ID, SYSDATE);
    delete from DelRecIndexes where (TableID=145) and (RecordId=new$ID);
  end if;

END;
/
-- ALTER TRIGGER tr_innerfinsource_ai_100
CREATE OR REPLACE TRIGGER TR_INNERFINSOURCE_II
  INSTEAD OF INSERT
  ON INNERFINSOURCE
  FOR EACH ROW
DECLARE
  new$ID INNERFINSOURCE.ID%TYPE := :NEW.ID;
  new$CREATEDATE INNERFINSOURCE.CREATEDATE%TYPE := :NEW.CREATEDATE;
  new$UPDATEDATE INNERFINSOURCE.UPDATEDATE%TYPE := :NEW.UPDATEDATE;
  new$DIRECTION INNERFINSOURCE.DIRECTION%TYPE := :NEW.DIRECTION;
  new$KVSR INNERFINSOURCE.KVSR%TYPE := :NEW.KVSR;
  new$DESCRIPTIONCODE INNERFINSOURCE.DESCRIPTIONCODE%TYPE := :NEW.DESCRIPTIONCODE;
  new$MAINDESCRIPTIONCODE INNERFINSOURCE.MAINDESCRIPTIONCODE%TYPE := :NEW.MAINDESCRIPTIONCODE;
  new$ITEMCODE INNERFINSOURCE.ITEMCODE%TYPE := :NEW.ITEMCODE;
  new$PROGRAMCODE INNERFINSOURCE.PROGRAMCODE%TYPE := :NEW.PROGRAMCODE;
  new$KESR INNERFINSOURCE.KESR%TYPE := :NEW.KESR;
  new$FINSOURCEVALUE INNERFINSOURCE.FINSOURCEVALUE%TYPE := :NEW.FINSOURCEVALUE;
  new$UNIONFLAG INNERFINSOURCE.UNIONFLAG%TYPE := :NEW.UNIONFLAG;
  new$REMOTEFLAG INNERFINSOURCE.REMOTEFLAG%TYPE := :NEW.REMOTEFLAG;
  new$BUDGETREF INNERFINSOURCE.BUDGETREF%TYPE := :NEW.BUDGETREF;
  new$DELETEDATE INNERFINSOURCE.DELETEDATE%TYPE := :NEW.DELETEDATE;
  new$NAME INNERFINSOURCE.NAME%TYPE := :NEW.NAME;
  new$STARTDATE INNERFINSOURCE.STARTDATE%TYPE := :NEW.STARTDATE;
  new$SHORTNAME INNERFINSOURCE.SHORTNAME%TYPE := :NEW.SHORTNAME;
  new$CLSASPECT INNERFINSOURCE.CLSASPECT%TYPE := :NEW.CLSASPECT;
  new$CREATERUSER INNERFINSOURCE.CREATERUSER%TYPE := :NEW.CREATERUSER;
  new$UPDATERUSER INNERFINSOURCE.UPDATERUSER%TYPE := :NEW.UPDATERUSER;
  new$IFS_LEVEL INNERFINSOURCE.IFS_LEVEL%TYPE := :NEW.IFS_LEVEL;
  new$EXTID INNERFINSOURCE.EXTID%TYPE := :NEW.EXTID;
  new$EXTOWNER INNERFINSOURCE.EXTOWNER%TYPE := :NEW.EXTOWNER;
  new$EXTSYNCDATE INNERFINSOURCE.EXTSYNCDATE%TYPE := :NEW.EXTSYNCDATE;
  new$EXTROOTID INNERFINSOURCE.EXTROOTID%TYPE := :NEW.EXTROOTID;
  new$EXTVERSION INNERFINSOURCE.EXTVERSION%TYPE := :NEW.EXTVERSION;
  new$EXTVERSIONDATE INNERFINSOURCE.EXTVERSIONDATE%TYPE := :NEW.EXTVERSIONDATE;
  new$ANALYTICALGROUPIFS INNERFINSOURCE.ANALYTICALGROUPIFS%TYPE := :NEW.ANALYTICALGROUPIFS;
--
  tmp$ NUMBER(15,0);
  tmp_Double$ NUMBER;
  sKVSR$ VARCHAR2(3);
  sDescrCode1$ VARCHAR2(7);
  sDescrCode2$ VARCHAR2(7);
  sAnalyticalGroupIFS$ VARCHAR2(3);
  CNT$1 NUMBER(10);
  DescrCode11$ NUMBER(10);
  DescrCode21$ NUMBER(10);
  KVSRCode$ NUMBER(10);
  sIFSLevel$ NUMBER(10);
  sDirection$ NUMBER(10);
BEGIN
-- - - - - - - - - - - - -
-- BI_0 (TR_INNERFINSOURCE_BI_0)
-- Version 11.00.00.1
-- - - - - - - - - - - - -

  /*  Id,     */
  if (new$id is null) then 
    select g_shared.nextval into new$id from dual;
  END IF;
  if (new$KVSR is null) then 
    new$KVSR := 0;
  END IF;
  if (new$AnalyticalGroupIFS is null) then 
    new$AnalyticalGroupIFS := 0;
  END IF;
  if (new$ClsAspect is null) then 
    new$ClsAspect := 0;
  END IF;
  if (new$UnionFlag is null) then 
    new$UnionFlag := 0;
  END IF;
  if (new$RemoteFlag is null) then 
    new$RemoteFlag := 0;
  END IF;
  if (new$BudgetRef is null) then 
    new$BudgetRef := 0;
  END IF;
  /*     */
  if (new$KVSR <> 0) then
    select max(IFS_Level), max(Direction)
    into sIFSLevel$, sDirection$     from innerfinsource 
    where ((AnalyticalGroupIFS = new$AnalyticalGroupIFS) and (BudgetRef=new$BudgetRef) and 
    (DESCRIPTIONCODE = new$DESCRIPTIONCODE) and (KVSR = 0)) 
    ;
  END IF;
  if (sIFSLevel$ is not null) then
    new$IFS_Level := sIFSLevel$;
  END IF;
  if (sDirection$ is not null) then
    new$Direction := sDirection$;
  END IF;
  /*         
            =3,5,8 */
  if (new$Direction is null) then
    if ((new$AnalyticalGroupIFS between 300 and 399) or 
    (new$AnalyticalGroupIFS between 500 and 599) or 
    (new$AnalyticalGroupIFS between 800 and 899)) then
      new$Direction := -1;
          
    else
      new$Direction := 1;
      
    END IF;
  END IF;
  BEGIN

    /*      */ 
    select Code into KVSRCode$ from KVSR where (ID = new$KVSR) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  /*  20-    */
  /*      */
  if (KVSRCode$ = 0) then
    sKVSR$ := '000';
        
  else
    if (KVSRCode$ < 10) then
      sKVSR$ := '00' || KVSRCode$;
          
    else
      if (KVSRCode$ < 100) then
        sKVSR$ := '0' || KVSRCode$;
            
      else
        sKVSR$ := KVSRCode$;
      END IF;
    END IF;
  END IF;
  /*    , ,  */
      
  tmp$ := new$DescriptionCode;
  tmp_Double$ := tmp$ / 1000000;
  DescrCode11$ := tmp_Double$;
  /*      ,
          ,    1 */
  if (DescrCode11$  > tmp_Double$) then 
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  new$MainDescriptionCode := DescrCode11$; /*    */
  /*       */    
  tmp_Double$ := DescrCode11$;
  tmp_Double$ := tmp$ - tmp_Double$ * 1000000;
  DescrCode21$ := tmp_Double$;
  tmp_Double$ := DescrCode21$ / 10000;
  DescrCode11$ := tmp_Double$;
  /*      */
  if (DescrCode11$ > tmp_Double$) then 
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  new$ItemCode := DescrCode11$; /* */
  tmp_Double$ := DescrCode21$ - DescrCode11$ * 10000;
  new$ProgramCode := tmp_Double$; /* */
  /*       */
      
  tmp_Double$ := tmp$ / 10000000;
  DescrCode11$ := tmp_Double$;
  if (DescrCode11$ > tmp_Double$) then 
    DescrCode11$ := DescrCode11$ - 1;
  END IF;
  tmp_Double$ := DescrCode11$;
  tmp_Double$ := tmp$ - tmp_Double$ * 10000000;
  DescrCode21$ := tmp_Double$;
  if (DescrCode11$ = 0) then
    sDescrCode1$ := '0000000';
        
  else
    if (DescrCode11$ < 10) then
      sDescrCode1$ := '000000' || DescrCode11$;
          
    else
      if (DescrCode11$ < 100) then
        sDescrCode1$ := '00000' || DescrCode11$;
            
      else
        if (DescrCode11$ < 1000) then
          sDescrCode1$ := '0000' || DescrCode11$;
              
        else
          if (DescrCode11$ < 10000) then
            sDescrCode1$ := '000' || DescrCode11$;
                
          else
            if (DescrCode11$ < 100000) then
              sDescrCode1$ := '00' || DescrCode11$;
                  
            else
              if (DescrCode11$ < 1000000) then
                sDescrCode1$ := '0' || DescrCode11$;
                    
              else
                sDescrCode1$ := DescrCode11$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  if (DescrCode21$ = 0) then
    sDescrCode2$ := '0000000';
        
  else
    if (DescrCode21$ < 10) then
      sDescrCode2$ := '000000' || DescrCode21$;
          
    else
      if (DescrCode21$ < 100) then
        sDescrCode2$ := '00000' || DescrCode21$;
            
      else
        if (DescrCode21$ < 1000) then
          sDescrCode2$ := '0000' || DescrCode21$;
              
        else
          if (DescrCode21$ < 10000) then
            sDescrCode2$ := '000' || DescrCode21$;
                
          else
            if (DescrCode21$ < 100000) then
              sDescrCode2$ := '00' || DescrCode21$;
                  
            else
              if (DescrCode21$ < 1000000) then
                sDescrCode2$ := '0' || DescrCode21$;
                    
              else
                sDescrCode2$ := DescrCode21$;
              END IF;
            END IF;
          END IF;
        END IF;
      END IF;
    END IF;
  END IF;
  BEGIN

    /*        */ 
    select Code into sAnalyticalGroupIFS$ from AnalyticalGroupIFS where (ID = new$AnalyticalGroupIFS) ;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN NULL;
  END;
  if (new$KESR is null) then
    new$KESR := sAnalyticalGroupIFS$;
  END IF;
  /*      */
      
  new$FinSourceValue := sKVSR$ || sDescrCode1$ || sDescrCode2$ || sAnalyticalGroupIFS$;
      
  if ((new$ID = 0) and (new$FinSourceValue <> '00000000000000000000') and (new$BudgetRef <> 0)) then
    RaiseException('ex_CantModify_ZeroIFS');
  END IF;

-- - - - - - - - - - - - -
-- BI_500 (TR_INNERFINSOURCE_BI_500)
-- Version 9.00.00.1
-- - - - - - - - - - - - -

  new$CreateDate := SYSDATE;
  new$UpdateDate := new$CreateDate;
  new$CreaterUser := user;
  new$UpdaterUser := user;

-- - - - - - - - - - - - -
-- INSERT
-- - - - - - - - - - - - -
  INSERT INTO TB_INNERFINSOURCE (
    ID,
    CREATEDATE,
    UPDATEDATE,
    DIRECTION,
    KVSR,
    DESCRIPTIONCODE,
    MAINDESCRIPTIONCODE,
    ITEMCODE,
    PROGRAMCODE,
    KESR,
    FINSOURCEVALUE,
    UNIONFLAG,
    REMOTEFLAG,
    BUDGETREF,
    DELETEDATE,
    NAME,
    STARTDATE,
    SHORTNAME,
    CLSASPECT,
    CREATERUSER,
    UPDATERUSER,
    IFS_LEVEL,
    EXTID,
    EXTOWNER,
    EXTSYNCDATE,
    EXTROOTID,
    EXTVERSION,
    EXTVERSIONDATE,
    ANALYTICALGROUPIFS
  ) VALUES (
    new$ID,
    new$CREATEDATE,
    new$UPDATEDATE,
    new$DIRECTION,
    new$KVSR,
    new$DESCRIPTIONCODE,
    new$MAINDESCRIPTIONCODE,
    new$ITEMCODE,
    new$PROGRAMCODE,
    new$KESR,
    new$FINSOURCEVALUE,
    new$UNIONFLAG,
    new$REMOTEFLAG,
    new$BUDGETREF,
    new$DELETEDATE,
    new$NAME,
    new$STARTDATE,
    new$SHORTNAME,
    new$CLSASPECT,
    new$CREATERUSER,
    new$UPDATERUSER,
    new$IFS_LEVEL,
    new$EXTID,
    new$EXTOWNER,
    new$EXTSYNCDATE,
    new$EXTROOTID,
    new$EXTVERSION,
    new$EXTVERSIONDATE,
    new$ANALYTICALGROUPIFS);

-- - - - - - - - - - - - -
-- AI_100 (TR_INNERFINSOURCE_AI_100)
-- Version 11.10.00.1
-- - - - - - - - - - - - -

  if (new$kvsr <> 0) then
    SELECT COUNT(*) INTO CNT$1
    from InnerFinSource ifs1
    where ((ifs1.kvsr = 0) and
    ((ifs1.descriptioncode-new$descriptioncode>-1) and (ifs1.descriptioncode-new$descriptioncode<1)) and
    (ifs1.AnalyticalGroupIFS = new$AnalyticalGroupIFS) and
    (ifs1.BudgetRef = new$BudgetRef) and
    ((ifs1.ExtID = new$ExtID)or((ifs1.ExtID is null)and(new$ExtID is null)))
    ) AND (ROWNUM = 1)                   ;
    if (not (CNT$1<> 0))
    then  
      insert into InnerFinSource (KVSR, DescriptionCode, AnalyticalGroupIFS, Name, ShortName, CLSAspect, RemoteFlag, Direction, IFS_Level, BudgetRef, ExtID)
      values (0, new$DescriptionCode, new$AnalyticalGroupIFS, new$Name, new$ShortName, new$CLSAspect, new$RemoteFlag, new$direction, new$IFS_Level, new$BudgetRef, new$ExtID);
      
    END IF;
  END IF;

-- - - - - - - - - - - - -
-- AI_500 (TR_INNERFINSOURCE_AI_500)
-- Last update 24.05.2005
-- - - - - - - - - - - - -

  delete from DelRecIndexes where (TableID = 145) and (RecordId = new$ID);

END;
/
commit work 
/


-- #########################################################
-- #########################################################
-- UpdDocFields_11.10.00_Ora.sql
-- #########################################################
-- #########################################################


--  : 111000 - 111000.     26.01.2016 10:21:45.
CREATE OR REPLACE PROCEDURE ImportDocType (
   ID_               NUMBER,
   PROGINDEX_        NUMBER,
   NAME_             VARCHAR2,
   USESTATE_         NUMBER,
   DBTABLE_          VARCHAR2,
   NEEDEDS_          NUMBER,
   LOCKMASK_         NUMBER,
   DEFAULTACTIONMACROSNAME_ VARCHAR2,
   DOCUMENTKIND_     NUMBER,
   SHORTNAME_         VARCHAR2
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentTypes
    WHERE (ID = ID_);

  IF (IDExists$ = 0) THEN
     INSERT INTO DocumentTypes
                 (ID, PROGINDEX, NAME, USESTATE, DBTABLE, NEEDEDS, LOCKMASK, DEFAULTACTIONMACROSNAME, DOCUMENTKIND, SHORTNAME)
          VALUES (ID_, PROGINDEX_, NAME_, USESTATE_, DBTABLE_, NEEDEDS_, LOCKMASK_, DEFAULTACTIONMACROSNAME_, DOCUMENTKIND_, SHORTNAME_);
  else
      Update documenttypes set
        Name=Name_,
                    DBTABLE=DBTABLE_,
        LockMask=LockMask_,
        DEFAULTACTIONMACROSNAME=DEFAULTACTIONMACROSNAME_,
        DOCUMENTKIND=DOCUMENTKIND_,
        SHORTNAME=SHORTNAME_,
              PROGINDEX=PROGINDEX_
      where (id=ID_)
        and (
          (Name<>Name_) or
          ((LockMask is null) and (LockMask_ is not null)) or
          ((LockMask is not null) and (LockMask_ is null)) or
          ((LockMask is not null) and (LockMask_ is not null) and (LockMask <> LockMask_)) or
          (DEFAULTACTIONMACROSNAME is null) or
          (DOCUMENTKIND<>DOCUMENTKIND_) or 
          (SHORTNAME is null) or 
          (SHORTNAME<>SHORTNAME_) or
          (PROGINDEX <> PROGINDEX_) or 
          ((DBTABLE is null) and (DBTABLE_ is not null)) or
          ((DBTABLE is not null) and (DBTABLE_ is null)) or
          ((DBTABLE is not null) and (DBTABLE_ is not null) and (DBTABLE <> DBTABLE_))
        );
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE UPDATEINTERFACES (
  CLS_   NUMBER,
  NOTE_  VARCHAR2,
  GUID_  VARCHAR2,
  PARAM_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT (ID)
   INTO IDEXISTS$
   FROM INTERFACES
  WHERE (GUID=GUID_);
  
  IF (IDExists$ = 0)  THEN
    INSERT INTO INTERFACES
      (CLS,NOTE,GUID,PARAM)
    VALUES
      (CLS_,NOTE_,GUID_,PARAM_);
  ELSE
    IF ((PARAM_ ='')OR(PARAM_ IS NULL)) THEN 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    ELSE 
      UPDATE INTERFACES SET
        CLS = CLS_
      WHERE (GUID=GUID_) AND (PARAM=PARAM_) AND ((CLS<> CLS_)OR(CLS IS NULL));
    END IF;
  END IF;
END;
/

--   
CALL ImportDocType(209, 274, ' ', 0, 'BudNotify[RVERSION=RVERSION-1]', 0,-1,'_',10100,'_') ;

CALL UpdateInterfaces(209, ' ', '{DA309359-EF6B-4D29-AC0D-309040B5CDB6}', '') ;

CALL ImportDocType(323, 75, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(324, 76, ' ', 0, 'FacialFinCaption', 0,-1,'_',10100,'') ;

CALL ImportDocType(1816, 0, '  ', 0, '', 0,-1,'',10200,'') ;

CALL UpdateInterfaces(1816, '  ', '{584B1826-AD94-47DC-A420-B5E42F2CA7D7}', '') ;

CALL ImportDocType(2504, 314, ' ', 0, 'Agreements', 0,-65537,'',10100,'') ;

CALL ImportDocType(4903, 527, ' ', 0, 'DataPacket', 0,-1,'_',10100,'') ;

CALL ImportDocType(9903, 0, ' ', 0, 'ORGANIZATIONS', 0,-1,'',10100,'_') ;

DROP PROCEDURE ImportDocType
/

DROP PROCEDURE UPDATEINTERFACES
/



CREATE OR REPLACE PROCEDURE SELECTIONS_IMPORT(
  ID_ NUMBER,
  KIND_ NUMBER,
  NAME_ VARCHAR2,
  NOTE_ VARCHAR2,
  READONLY_ NUMBER,
  USEINDOC_ NUMBER,
  TABLENAME_ VARCHAR2,
  ALIAS_ VARCHAR2,
  TABLECODE_ NUMBER,
  NEEDGROUPONDB_ NUMBER,
  NEEDDISTINCT_ NUMBER,
  MASTER_ NUMBER,
  DISCRIMVALUE_ VARCHAR2,
  AVAILABLEINDEREF_ NUMBER,
  CACHETYPE_ NUMBER,
  FULLORMODINSREFRTIME_ NUMBER,
  DELETEREFRTIME_ NUMBER,
  FINDTIMEREFRESH_ NUMBER,
  ANNOTATION_ VARCHAR2,
  DEREFNAME_ VARCHAR2,
  GroupID_ NUMBER,
  IsLogged_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONS SET
      KIND = KIND_,
      NAME = NAME_,
      NOTE = NOTE_,
      READONLY = READONLY_,
      USEINDOC = USEINDOC_,
      TABLENAME = TABLENAME_,
      ALIAS = ALIAS_,
      TABLECODE = TABLECODE_,    
      NEEDGROUPONDB = NEEDGROUPONDB_,
      NEEDDISTINCT = NEEDDISTINCT_,
      MASTER = MASTER_,
      DISCRIMVALUE = DISCRIMVALUE_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,         
      CACHETYPE = CACHETYPE_,   
      FULLORMODINSREFRTIME = FULLORMODINSREFRTIME_,   
      DELETEREFRTIME = DELETEREFRTIME_,   
      FINDTIMEREFRESH = FINDTIMEREFRESH_,   
      ANNOTATION = ANNOTATION_,   
      DEREFNAME = DEREFNAME_,     
      GroupID = GroupID_, 
      IsLogged = IsLogged_  
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONS
      (ID, KIND, NAME, NOTE, READONLY, USEINDOC, TABLENAME, ALIAS, TABLECODE, NEEDGROUPONDB, NEEDDISTINCT, MASTER, DISCRIMVALUE,
      AVAILABLEINDEREF, CACHETYPE, FULLORMODINSREFRTIME, DELETEREFRTIME, FINDTIMEREFRESH, ANNOTATION, DEREFNAME, GroupID, IsLogged)
    VALUES
      (ID_, KIND_, NAME_, NOTE_, READONLY_, USEINDOC_, TABLENAME_, ALIAS_, TABLECODE_, NEEDGROUPONDB_, NEEDDISTINCT_, MASTER_, DISCRIMVALUE_,
      AVAILABLEINDEREF_, CACHETYPE_, FULLORMODINSREFRTIME_, DELETEREFRTIME_, FINDTIMEREFRESH_, ANNOTATION_, DEREFNAME_, GroupID_, IsLogged_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  ALIAS_ VARCHAR2,
  JOINORDER_ NUMBER,
  JOINTYPE_ NUMBER,
  RELATIONTYPE_ NUMBER,
  JOINCONDITION_ VARCHAR2,
  DONTUSETABLELIMITS_ NUMBER,
  LIMITNAMESLIST_ VARCHAR2,
  QueryGroup_ NUMBER  
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONSDETAIL
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONSDETAIL SET
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      ALIAS = ALIAS_,
      JOINORDER = JOINORDER_,
      JOINTYPE = JOINTYPE_,
      RELATIONTYPE = RELATIONTYPE_,
      JOINCONDITION = JOINCONDITION_,
      DONTUSETABLELIMITS = DONTUSETABLELIMITS_,
      LIMITNAMESLIST = LIMITNAMESLIST_,
      QueryGroup = QueryGroup_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONSDETAIL
      (ID, SELECTIONREF, TABLEREF, ALIAS, JOINORDER, JOINTYPE, RELATIONTYPE, JOINCONDITION, DONTUSETABLELIMITS, LIMITNAMESLIST, QueryGroup)
    VALUES
      (ID_, SELECTIONREF_, TABLEREF_, ALIAS_, JOINORDER_, JOINTYPE_, RELATIONTYPE_, JOINCONDITION_, DONTUSETABLELIMITS_, LIMITNAMESLIST_, QueryGroup_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_IMPORT(
  ID_ NUMBER,
  FIELDKIND_ NUMBER,
  DESCRIPTIONLEVEL_ NUMBER,
  ANCESTORREF_ NUMBER,
  SELECTIONREF_ NUMBER,
  TABLEREF_ NUMBER,
  FIELDNAME_ VARCHAR2,
  DATATYPE_ NUMBER,
  SUBDATATYPE_ NUMBER,
  FIELDSIZE_ NUMBER,
  DISPLAYLABEL_ VARCHAR2,
  NOTE_ VARCHAR2,
  DEFAULTWIDTH_ NUMBER,
  EDITMASK_ VARCHAR2,
  DISPLAYFORMAT_ VARCHAR2,
  EDITFORMAT_ VARCHAR2,
  CANTEDIT_ NUMBER,
  NOVISUALIZE_ NUMBER,
  ENUMSREF_ NUMBER,
  REQUIRED_ NUMBER,
  FOREIGNKEY_ NUMBER,
  ONDELACTION_ NUMBER,
  PRIMARYKEY_ NUMBER,
  ISRVERSION_ NUMBER,
  LIMITPARAMNAMES_ VARCHAR2,
  FOLLOWORDER_ NUMBER,
  SORTDIRECTION_ NUMBER,
  SORTORDER_ NUMBER,
  AGRFUNCTION_ NUMBER,
  FLAGFIELDNAME_ NUMBER,
  FLAGDISPLAYLABEL_ NUMBER,
  FLAGNOTE_ NUMBER,
  FLAGDEFAULTWIDTH_ NUMBER,
  FLAGCANTEDIT_ NUMBER,
  FLAGNOVISUALIZE_ NUMBER,
  FLAGREQUIRED_ NUMBER,
  FLAGLIMITPARAMNAMES_ NUMBER,
  FLAGAGRFUNCTION_ NUMBER,
  ISTIMESTAMPFIELD_ NUMBER,
  ISBUDGET_ NUMBER,
  AVAILABLEINDEREF_ NUMBER,
  ANNOTATION_ VARCHAR2,
  ALIAS_ VARCHAR2,
  DEREFNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM FIELDSINFO
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE FIELDSINFO SET
      FIELDKIND = FIELDKIND_,
      DESCRIPTIONLEVEL = DESCRIPTIONLEVEL_,
      ANCESTORREF = ANCESTORREF_,
      SELECTIONREF = SELECTIONREF_,
      TABLEREF = TABLEREF_,
      FIELDNAME = FIELDNAME_,
      DATATYPE = DATATYPE_,
      SUBDATATYPE = SUBDATATYPE_,
      FIELDSIZE = FIELDSIZE_,
      DISPLAYLABEL = DISPLAYLABEL_,
      NOTE = NOTE_,
      DEFAULTWIDTH = DEFAULTWIDTH_,
      EDITMASK = EDITMASK_,
      DISPLAYFORMAT = DISPLAYFORMAT_,
      EDITFORMAT = EDITFORMAT_,
      CANTEDIT = CANTEDIT_,
      NOVISUALIZE = NOVISUALIZE_,
      ENUMSREF = ENUMSREF_,
      REQUIRED = REQUIRED_,
      FOREIGNKEY = FOREIGNKEY_,
      ONDELACTION = ONDELACTION_,
      PRIMARYKEY = PRIMARYKEY_,
      ISRVERSION = ISRVERSION_,
      LIMITPARAMNAMES = LIMITPARAMNAMES_,
      FOLLOWORDER = FOLLOWORDER_,
      SORTDIRECTION = SORTDIRECTION_,
      SORTORDER = SORTORDER_,
      AGRFUNCTION = AGRFUNCTION_,
      FLAGFIELDNAME = FLAGFIELDNAME_,
      FLAGDISPLAYLABEL = FLAGDISPLAYLABEL_,
      FLAGNOTE = FLAGNOTE_,
      FLAGDEFAULTWIDTH = FLAGDEFAULTWIDTH_,
      FLAGCANTEDIT = FLAGCANTEDIT_,
      FLAGNOVISUALIZE = FLAGNOVISUALIZE_,
      FLAGREQUIRED = FLAGREQUIRED_,
      FLAGLIMITPARAMNAMES = FLAGLIMITPARAMNAMES_,
      FLAGAGRFUNCTION = FLAGAGRFUNCTION_,
      ISTIMESTAMPFIELD = ISTIMESTAMPFIELD_,
      ISBUDGET = ISBUDGET_,
      AVAILABLEINDEREF = AVAILABLEINDEREF_,
      ANNOTATION = ANNOTATION_,
      ALIAS = ALIAS_,
      DEREFNAME = DEREFNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO FIELDSINFO
      (ID, FIELDKIND, DESCRIPTIONLEVEL, ANCESTORREF, SELECTIONREF, TABLEREF, FIELDNAME, DATATYPE, SUBDATATYPE,
       FIELDSIZE, DISPLAYLABEL, NOTE, DEFAULTWIDTH, EDITMASK, DISPLAYFORMAT, EDITFORMAT, CANTEDIT, NOVISUALIZE,
       ENUMSREF, REQUIRED, FOREIGNKEY, ONDELACTION, PRIMARYKEY, ISRVERSION, LIMITPARAMNAMES,
       FOLLOWORDER, SORTDIRECTION, SORTORDER, AGRFUNCTION, FLAGFIELDNAME, FLAGDISPLAYLABEL, FLAGNOTE,
       FLAGDEFAULTWIDTH, FLAGCANTEDIT, FLAGNOVISUALIZE, FLAGREQUIRED, FLAGLIMITPARAMNAMES, FLAGAGRFUNCTION,
       ISTIMESTAMPFIELD, ISBUDGET, AVAILABLEINDEREF, ANNOTATION, ALIAS, DEREFNAME)
    VALUES
      (ID_, FIELDKIND_, DESCRIPTIONLEVEL_, ANCESTORREF_, SELECTIONREF_, TABLEREF_, FIELDNAME_, DATATYPE_, SUBDATATYPE_,
       FIELDSIZE_, DISPLAYLABEL_, NOTE_, DEFAULTWIDTH_, EDITMASK_, DISPLAYFORMAT_, EDITFORMAT_, CANTEDIT_, NOVISUALIZE_,
       ENUMSREF_, REQUIRED_, FOREIGNKEY_, ONDELACTION_, PRIMARYKEY_, ISRVERSION_, LIMITPARAMNAMES_,
       FOLLOWORDER_, SORTDIRECTION_, SORTORDER_, AGRFUNCTION_, FLAGFIELDNAME_, FLAGDISPLAYLABEL_, FLAGNOTE_,
       FLAGDEFAULTWIDTH_, FLAGCANTEDIT_, FLAGNOVISUALIZE_, FLAGREQUIRED_, FLAGLIMITPARAMNAMES_, FLAGAGRFUNCTION_,
       ISTIMESTAMPFIELD_, ISBUDGET_, AVAILABLEINDEREF_, ANNOTATION_, ALIAS_, DEREFNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_IMPORT(
  ID_ NUMBER,
  SELECTIONREF_ NUMBER,
  EVENTCODE_ NUMBER,
  SCRIPTNAME_ VARCHAR2
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM SELECTIONEVENTS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE SELECTIONEVENTS SET
      SELECTIONREF = SELECTIONREF_,
      EVENTCODE = EVENTCODE_,
      SCRIPTNAME = SCRIPTNAME_
    WHERE ID = ID_;
  ELSE
    INSERT INTO SELECTIONEVENTS
      (ID, SELECTIONREF, EVENTCODE, SCRIPTNAME)
    VALUES
      (ID_, SELECTIONREF_, EVENTCODE_, SCRIPTNAME_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FIELDSINFO_DELETE(
  ID_ NUMBER
) IS
BEGIN
  UPDATE DOCUMENTFIELDS SET
    FIELDINFOREF = NULL
  WHERE FIELDINFOREF = ID_;
  DELETE FROM FIELDSINFO FI
  WHERE FI.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONSDETAIL_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONSDETAIL SLD
  WHERE SLD.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONS SL
  WHERE SL.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE SELECTIONEVENTS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM SELECTIONEVENTS SE
  WHERE SE.ID = ID_;
END;
/

-- 
CALL SELECTIONS_IMPORT(38766, 2, 'CLS_324', '', 1, 0, '', '', 0, 1, 0, 1, '', 0, 1, 20, null, null, 'PERSISTENT=STOREDAYCOUNT=7,Composite=', '', null, 0) ;

-- BUHACCPLAN
CALL FIELDSINFO_IMPORT(21630, 0, 1, null, 21627, null, 'ECCLS', 1, 0, 20, ' ', '', 4, '>aaa', '', '', 0, 0, null, 1, null, 0, 0, 0, '', 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

CALL FIELDSINFO_IMPORT(39104, 0, 1, null, 21627, null, 'CLSTYPE', 3, 0, 0, '', '', 20, '', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', '', '') ;

-- CLS_323
CALL FIELDSINFO_IMPORT(34619, 0, 2, 19007, 34610, 34612, 'BUHOPERATIONCLS', 3, 0, 0, '  ', '   70  ', 11, '', '', '', 0, 0, null, 1, 21634, 0, 0, 0, '', 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUHOPERATIONCLS', '') ;

-- CLS_324
CALL FIELDSINFO_IMPORT(38770, 0, 2, 19007, 38766, 38767, 'BUHOPERATIONCLS', 3, 0, 0, '  ', '   70  ', 11, '', '', '', 0, 0, null, 1, 21634, 0, 0, 0, '', 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 1, '', 'BUHOPERATIONCLS', '') ;

CALL FIELDSINFO_IMPORT(38772, 0, 2, 34968, 38766, 38767, 'DOCCHANGEDATE', 11, 0, 0, '   ', ' ,  ', 20, '99/99/9999', '', '', 0, 0, null, 0, null, 0, 0, 0, '', 4, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, '', 'DOCCHANGEDATE', '') ;

CALL FIELDSINFO_IMPORT(38773, 0, 2, 18948, 38766, 38767, 'ID', 3, 0, 0, ' ', '  ()', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 5, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, '', 'CAPTIONID', '') ;

CALL FIELDSINFO_IMPORT(38790, 0, 2, 18865, 38766, 38768, 'ID', 3, 0, 0, ' ', '   ', 11, '', '', '', 2, 0, null, 1, null, 0, 1, 0, '', 22, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 2, 1, '', 'RECORDCOUNT', '') ;

--  
DROP PROCEDURE SELECTIONS_IMPORT
/

DROP PROCEDURE SELECTIONSDETAIL_IMPORT
/

DROP PROCEDURE FIELDSINFO_IMPORT
/

DROP PROCEDURE SELECTIONEVENTS_IMPORT
/

DROP PROCEDURE FIELDSINFO_DELETE
/

DROP PROCEDURE SELECTIONSDETAIL_DELETE
/

DROP PROCEDURE SELECTIONS_DELETE
/

DROP PROCEDURE SELECTIONEVENTS_DELETE
/

CREATE OR REPLACE PROCEDURE ImportDocCLS (
   ID_                 NUMBER,
   DOCTYPE_            NUMBER,
   DOCTYPENOTE_        VARCHAR2,
   TABLENAME_          VARCHAR2,
   TABLENAMEURM_       VARCHAR2,
   PRIMARYKEYNAME_     VARCHAR2,
   PRIMARYKEYNAMEURM_  VARCHAR2,
   LINKFIELDNAME_      VARCHAR2,
   LINKFIELDNAMEURM_   VARCHAR2,
   CLSTYPE_            NUMBER,
   SELECTIONREFBUDGET_ NUMBER,
   SELECTIONREFURM_    NUMBER,
   PROGINDEX_          NUMBER
) IS IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
   INTO IDExists$
   FROM DOCUMENTCLS
   WHERE (ID = ID_);

   IF (IDExists$ = 0) THEN
   INSERT INTO DOCUMENTCLS
   (ID, DOCTYPE, DOCTYPENOTE, TABLENAME, TABLENAMEURM, PRIMARYKEYNAME, PRIMARYKEYNAMEURM, LINKFIELDNAME, LINKFIELDNAMEURM, CLSTYPE, 
     SELECTIONREFBUDGET, SELECTIONREFURM, PROGINDEX)
   VALUES (ID_, DOCTYPE_, DOCTYPENOTE_, TABLENAME_, TABLENAMEURM_, PRIMARYKEYNAME_, PRIMARYKEYNAMEURM_, LINKFIELDNAME_, LINKFIELDNAMEURM_, CLSTYPE_, 
     SELECTIONREFBUDGET_, SELECTIONREFURM_, PROGINDEX_);
   ELSE
   UPDATE DOCUMENTCLS 
   SET
     DOCTYPENOTE = DOCTYPENOTE_,
     TABLENAME = TABLENAME_,
     TABLENAMEURM = TABLENAMEURM_,
     PRIMARYKEYNAME = PRIMARYKEYNAME_,
     PRIMARYKEYNAMEURM = PRIMARYKEYNAMEURM_,
     LINKFIELDNAME = LINKFIELDNAME_,
     LINKFIELDNAMEURM = LINKFIELDNAMEURM_,
     CLSTYPE = CLSTYPE_,
     SELECTIONREFBUDGET = SELECTIONREFBUDGET_,
     SELECTIONREFURM = SELECTIONREFURM_,
     PROGINDEX = PROGINDEX_
   WHERE  
    (ID = ID_)
    AND NOT (
            (
                    ((DOCTYPENOTE IS NOT NULL AND DOCTYPENOTE_ IS NOT NULL) AND
                       (UPPER (DOCTYPENOTE) = UPPER (DOCTYPENOTE_))
                    )
                    OR (DOCTYPENOTE IS NULL AND DOCTYPENOTE_ IS NULL)
                )    
        AND (UPPER (TABLENAME) = UPPER (TABLENAME_))    
        AND (
                    ((TABLENAMEURM IS NOT NULL AND TABLENAMEURM_ IS NOT NULL) AND
                       (UPPER (TABLENAMEURM) = UPPER (TABLENAMEURM_))
                    )
                    OR (TABLENAMEURM IS NULL AND TABLENAMEURM_ IS NULL)
                )    
        AND (UPPER (PRIMARYKEYNAME) = UPPER (PRIMARYKEYNAME_))
        AND (
                    ((PRIMARYKEYNAMEURM IS NOT NULL AND PRIMARYKEYNAMEURM_ IS NOT NULL) AND
                       (UPPER (PRIMARYKEYNAMEURM) = UPPER (PRIMARYKEYNAMEURM_))
                    )
                    OR (PRIMARYKEYNAMEURM IS NULL AND PRIMARYKEYNAMEURM_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAME IS NOT NULL AND LINKFIELDNAME_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAME) = UPPER (LINKFIELDNAME_))
                    )
                    OR (LINKFIELDNAME IS NULL AND LINKFIELDNAME_ IS NULL)
                )    
        AND (
                    ((LINKFIELDNAMEURM IS NOT NULL AND LINKFIELDNAMEURM_ IS NOT NULL) AND
                       (UPPER (LINKFIELDNAMEURM) = UPPER (LINKFIELDNAMEURM_))
                    )
                    OR (LINKFIELDNAMEURM IS NULL AND LINKFIELDNAMEURM_ IS NULL)
                )    
        AND (
                    ((CLSTYPE IS NOT NULL AND CLSTYPE_ IS NOT NULL) AND
                       (UPPER (CLSTYPE) = UPPER (CLSTYPE_))
                    )
                    OR (CLSTYPE IS NULL AND CLSTYPE_ IS NULL)
                ) 
        AND (
                    ((PROGINDEX IS NOT NULL AND PROGINDEX_ IS NOT NULL) AND
                       (PROGINDEX = PROGINDEX_)
                    )
                    OR (PROGINDEX IS NULL AND PROGINDEX_ IS NULL)
                )   
            );
   
   END IF;
END;
/

--   
CALL ImportDocCLS(10100, 101, '', 'FINDOCCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 223) ;

CALL ImportDocCLS(10101, 101, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, 223) ;

CALL ImportDocCLS(10102, 101, ' ', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10103, 101, ' ', 'DEBT', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10104, 101, ' %  ', 'FINDOCDETAIL', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(10105, 101, ' ', 'INCOMES32', ' ', 'ID', ' ', 'TOTALREF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20100, 201, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 32) ;

CALL ImportDocCLS(20101, 201, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 32) ;

CALL ImportDocCLS(30100, 301, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 66) ;

CALL ImportDocCLS(30101, 301, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 66) ;

CALL ImportDocCLS(30200, 302, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 63) ;

CALL ImportDocCLS(30201, 302, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 63) ;

CALL ImportDocCLS(30300, 303, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 65) ;

CALL ImportDocCLS(30301, 303, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 65) ;

CALL ImportDocCLS(30400, 304, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 64) ;

CALL ImportDocCLS(30401, 304, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 64) ;

CALL ImportDocCLS(30500, 305, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 61) ;

CALL ImportDocCLS(30501, 305, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 61) ;

CALL ImportDocCLS(30600, 306, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 62) ;

CALL ImportDocCLS(30601, 306, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 62) ;

CALL ImportDocCLS(30700, 307, '', 'FACIALFINREESTR', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(31100, 311, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 68) ;

CALL ImportDocCLS(31101, 311, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 68) ;

CALL ImportDocCLS(31200, 312, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 69) ;

CALL ImportDocCLS(31201, 312, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 69) ;

CALL ImportDocCLS(31400, 314, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 70) ;

CALL ImportDocCLS(31401, 314, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 70) ;

CALL ImportDocCLS(31500, 315, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 71) ;

CALL ImportDocCLS(31501, 315, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 71) ;

CALL ImportDocCLS(992500, 9925, '', 'Cards', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992501, 9925, ' ', 'CARDSDETAIL_FACC', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(490300, 4903, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 527) ;

CALL ImportDocCLS(32200, 322, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 73) ;

CALL ImportDocCLS(32201, 322, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 73) ;

CALL ImportDocCLS(32300, 323, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 75) ;

CALL ImportDocCLS(32301, 323, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 75) ;

CALL ImportDocCLS(32400, 324, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 76) ;

CALL ImportDocCLS(32401, 324, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 76) ;

CALL ImportDocCLS(40100, 401, '', 'LOANCREDIT', ' ', 'ID', ' ', '', ' ', 0, null, null, 130) ;

CALL ImportDocCLS(40101, 401, '', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 131) ;

CALL ImportDocCLS(40102, 401, ' ', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 137) ;

CALL ImportDocCLS(40103, 401, '', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 132) ;

CALL ImportDocCLS(40104, 401, ' %', 'LOANCREDITPERCENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 134) ;

CALL ImportDocCLS(40105, 401, '  %', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 138) ;

CALL ImportDocCLS(40106, 401, ' %', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 133) ;

CALL ImportDocCLS(40107, 401, ' %', 'PERCENTJOURNAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(40108, 401, '. ', 'DEBT', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(40109, 401, '', 'COLLATERAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 340) ;

CALL ImportDocCLS(40110, 401, '.', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 341) ;

CALL ImportDocCLS(40111, 401, '', 'LOANCREDITCONTRACTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 342) ;

CALL ImportDocCLS(50100, 501, '', 'LOANCREDIT', ' ', 'ID', ' ', '', ' ', 0, null, null, 120) ;

CALL ImportDocCLS(50101, 501, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 121) ;

CALL ImportDocCLS(50102, 501, ' ', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 127) ;

CALL ImportDocCLS(50103, 501, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 122) ;

CALL ImportDocCLS(50104, 501, ' %', 'LOANCREDITPERCENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 124) ;

CALL ImportDocCLS(50105, 501, '  %', 'LOANCREDITPLAN', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 128) ;

CALL ImportDocCLS(50106, 501, ' %', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 123) ;

CALL ImportDocCLS(50107, 501, ' %', 'PERCENTJOURNAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(50108, 501, '', 'COLLATERAL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 321) ;

CALL ImportDocCLS(70100, 701, '', 'FINDOCCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 23) ;

CALL ImportDocCLS(70101, 701, '', 'FINDOCDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 23) ;

CALL ImportDocCLS(70200, 702, '', 'PAYDOC32', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(70201, 702, '', 'PAYDOC32', ' ', 'ID', ' ', 'PARENTINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(70300, 703, '', 'FINDOCDETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, 36) ;

CALL ImportDocCLS(80100, 801, '', 'LIMITNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80101, 801, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 57) ;

CALL ImportDocCLS(80200, 802, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80300, 803, '', 'REQUESTFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80301, 803, '', 'LIMITFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(80400, 804, '', 'LIMITFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(90100, 901, '', 'QUOTESTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, 145) ;

CALL ImportDocCLS(90101, 901, '', 'INCOMES32', ' ', 'ID', ' ', 'RecordIndex', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90300, 903, '', 'QUOTESTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90301, 903, '', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 45) ;

CALL ImportDocCLS(90500, 905, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 44) ;

CALL ImportDocCLS(90600, 906, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 41) ;

CALL ImportDocCLS(90601, 906, '', 'INCOMES32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 42) ;

CALL ImportDocCLS(120100, 1201, '', 'BUH_JOURNAL', ' ', 'ID', ' ', '', ' ', 0, null, null, 309) ;

CALL ImportDocCLS(150100, 1501, '', 'ORGOPERAT', ' ', 'ID', ' ', '', ' ', 0, null, null, 35) ;

CALL ImportDocCLS(160100, 1601, '', 'PROMISE_CAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(160101, 1601, '', 'PROMISE_DETAIL', ' ', 'ID', ' ', 'TITLE_REF', ' ', 0, null, null, 345) ;

CALL ImportDocCLS(160200, 1602, '', 'PROMISE_DETAIL', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(170100, 1701, '', 'REQUESTS', ' ', 'ID', ' ', '', ' ', 0, null, null, 222) ;

CALL ImportDocCLS(170200, 1702, '', 'REQUESTS', ' ', 'ID', ' ', '', ' ', 0, null, null, 221) ;

CALL ImportDocCLS(170201, 1702, '', 'REQUESTSPAYMENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(190100, 1901, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 264) ;

CALL ImportDocCLS(190101, 1901, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 264) ;

CALL ImportDocCLS(220100, 2201, '', 'BUDNOTIFY', 'BUDNOTIFY', 'ID', ' ', '', ' ', 0, null, null, 46) ;

CALL ImportDocCLS(220101, 2201, '', 'BUDGETDATA', 'BUDGETDATA', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 46) ;

CALL ImportDocCLS(280100, 2801, '', 'ACCSOPERTITLE', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(280101, 2801, '', 'PAYDOC32', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 16) ;

CALL ImportDocCLS(280200, 2802, '', 'DFACCOUNTOPERATION', ' ', 'ID', ' ', '', ' ', 0, null, null, 50) ;

CALL ImportDocCLS(440100, 4401, '', 'UNIONNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 251) ;

CALL ImportDocCLS(440101, 4401, '', 'UNIONNOTIFYDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 251) ;

CALL ImportDocCLS(0, 0, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991304, 9913, ' ', 'STATICLINKS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(440300, 4403, '', 'UNIONNOTIFYCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 254) ;

CALL ImportDocCLS(440301, 4403, '', 'UNIONNOTIFYDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 254) ;

CALL ImportDocCLS(989500, 9895, ' ', 'OKTMO', 'OKTMO', 'id', 'id', '', '', 95, null, null, null) ;

CALL ImportDocCLS(990300, 9903, '', 'ORGANIZATIONS', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990301, 9903, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', 'ORG_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990302, 9903, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', 'ORG_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(990500, 9905, '', 'ORGANIZATIONS', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(90200, 902, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, 38) ;

CALL ImportDocCLS(20701, 207, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 272) ;

CALL ImportDocCLS(90700, 907, '', 'INCOMES32', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(181200, 1812, '', 'ED_CorrectionCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181000, 1810, '', 'ED_OUTPAYDOC', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20700, 207, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 272) ;

CALL ImportDocCLS(181001, 1810, '', 'ED_DETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(992700, 9927, '', 'REMOTECLIENT', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(550100, 5501, '', 'CORRECTIONCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 312) ;

CALL ImportDocCLS(20801, 208, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 273) ;

CALL ImportDocCLS(30701, 307, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', 'REESTR_REF', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21100, 211, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 275) ;

CALL ImportDocCLS(490100, 4901, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 525) ;

CALL ImportDocCLS(992701, 9927, '  ', 'REMOTEREADRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(550101, 5501, '', 'CORRECTIONDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 312) ;

CALL ImportDocCLS(490301, 4903, '', 'ARCHIVEOPLOG', ' ', 'ID', ' ', 'DATAPACKETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(390100, 3901, '', 'DELOIN', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21101, 211, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 275) ;

CALL ImportDocCLS(992300, 9923, '', 'SIGNSCHEMECAPTION', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181201, 1812, '', 'ED_CorrectionDetail', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(550200, 5502, '', 'CORRECTIONCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 313) ;

CALL ImportDocCLS(20800, 208, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 273) ;

CALL ImportDocCLS(550201, 5502, '', 'CORRECTIONDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 313) ;

CALL ImportDocCLS(90000, 900, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992301, 9923, '', 'SIGNSCHEMEDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(991600, 9916, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992200, 9922, '', 'ARCHIVEDOCTYPE', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(90001, 900, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(390101, 3901, '', 'DELOEXEC', ' ', 'ID', ' ', 'DOCID', ' ', 0, null, null, null) ;

CALL ImportDocCLS(180700, 1807, '', 'PayDocExchange', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(21102, 211, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 275) ;

CALL ImportDocCLS(991700, 9917, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991200, 9912, '', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(181600, 1816, '', 'FacialFinCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(30800, 308, '', 'FACIALFINCAPTION', ' ', 'ID', ' ', '', ' ', 0, null, null, 67) ;

CALL ImportDocCLS(250100, 2501, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', ' ', 0, null, null, 305) ;

CALL ImportDocCLS(21200, 212, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 276) ;

CALL ImportDocCLS(250101, 2501, '  ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 305) ;

CALL ImportDocCLS(30801, 308, '', 'FACIALFINDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 67) ;

CALL ImportDocCLS(250200, 2502, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', ' ', 0, null, null, 304) ;

CALL ImportDocCLS(250201, 2502, ' ', 'AGREEMENTSTEPS', 'AGREEMENTSTEPS', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(988900, 9889, ' ', 'SubsidyCls', ' ', 'id', ' ', '', '', 89, null, null, null) ;

CALL ImportDocCLS(250202, 2502, '  ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'AGREEMENTREF', 'AGREEMENTREF', 0, null, null, 304) ;

CALL ImportDocCLS(988700, 9887, ' ', 'VariantCls', ' ', 'ID', ' ', '', '', 87, null, null, null) ;

CALL ImportDocCLS(520100, 5201, '', 'WritExecutionCaption', 'WritExecutionCaption', 'id', 'id', '', '', 0, null, null, 555) ;

CALL ImportDocCLS(990800, 9908, '', 'DocumentTypes', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(250300, 2503, '', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', '', ' ', 0, null, null, null) ;

CALL ImportDocCLS(21201, 212, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 276) ;

CALL ImportDocCLS(250301, 2503, '', 'EXECUTIONDOCUMENTSDETAIL', 'EXECUTIONDOCUMENTSDETAIL', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(180500, 1805, '', 'BANKEXCH_MERDOC', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(20201, 202, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 260) ;

CALL ImportDocCLS(20301, 203, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 261) ;

CALL ImportDocCLS(20401, 204, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 262) ;

CALL ImportDocCLS(20501, 205, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 263) ;

CALL ImportDocCLS(20601, 206, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 268) ;

CALL ImportDocCLS(190201, 1902, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 215) ;

CALL ImportDocCLS(190301, 1903, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 265) ;

CALL ImportDocCLS(20000, 200, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190601, 1906, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, 271) ;

CALL ImportDocCLS(20200, 202, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 260) ;

CALL ImportDocCLS(20300, 203, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 261) ;

CALL ImportDocCLS(20400, 204, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 262) ;

CALL ImportDocCLS(20500, 205, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 263) ;

CALL ImportDocCLS(20600, 206, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 268) ;

CALL ImportDocCLS(190200, 1902, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 215) ;

CALL ImportDocCLS(190300, 1903, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 265) ;

CALL ImportDocCLS(180501, 1805, '', 'ED_DETAIL', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(190600, 1906, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', ' ', 0, null, null, 271) ;

CALL ImportDocCLS(988400, 9884, ' ', 'TransfertCLS', ' ', 'ID', ' ', '', '', 84, null, null, null) ;

CALL ImportDocCLS(988800, 9888, ' ', 'OKP', ' ', 'ID', ' ', '', '', 88, null, null, null) ;

CALL ImportDocCLS(989900, 9899, ' ', 'DBUsers', ' ', 'ID', ' ', '', '', 201, null, null, null) ;

CALL ImportDocCLS(990801, 9908, ' ', 'DOCUMENTFIELDS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(361000, 3610, '', 'UTYPEDFORMSCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 550) ;

CALL ImportDocCLS(987200, 9872, ' ', 'BalanceCls', ' ', 'ID', ' ', '', '', 72, null, null, null) ;

CALL ImportDocCLS(984600, 9846, ' ', 'BUHPAYMENTCLS', ' ', 'ID', ' ', '', '', 46, null, null, null) ;

CALL ImportDocCLS(981800, 9818, ' ', 'CURRENCYCLS', ' ', 'ID', ' ', '', '', 18, null, null, null) ;

CALL ImportDocCLS(988500, 9885, ' ', 'AssignmentKind', ' ', 'ID', ' ', '', '', 85, null, null, null) ;

CALL ImportDocCLS(983500, 9835, ' ', 'BUDGETTYPE', ' ', 'ID', ' ', '', '', 35, null, null, null) ;

CALL ImportDocCLS(985800, 9858, ' ', 'DEBTTYPE', ' ', 'ID', ' ', '', '', 58, null, null, null) ;

CALL ImportDocCLS(988600, 9886, ' ', 'AssignmentSource', ' ', 'ID', ' ', ' ', ' ', 86, null, null, null) ;

CALL ImportDocCLS(988300, 9883, ' ', 'Org_Type', ' ', 'ID', ' ', '', '', 83, null, null, null) ;

CALL ImportDocCLS(986400, 9864, ' ', 'PlanDocType', ' ', 'ID', ' ', '', '', 64, null, null, null) ;

CALL ImportDocCLS(985700, 9857, ' ', 'LOANTYPE', ' ', 'ID', ' ', '', '', 57, null, null, null) ;

CALL ImportDocCLS(984300, 9843, ' ', 'PAYTYPECLS', ' ', 'ID', ' ', '', '', 43, null, null, null) ;

CALL ImportDocCLS(982300, 9823, ' ', 'GOSNI', ' ', 'ID', ' ', '', '', 23, null, null, null) ;

CALL ImportDocCLS(982200, 9822, ' ', 'GroupInf_CLS', ' ', 'ID', ' ', '', '', 22, null, null, null) ;

CALL ImportDocCLS(982900, 9829, ' ', 'DocBase', ' ', 'ID', ' ', '', '', 29, null, null, null) ;

CALL ImportDocCLS(981100, 9811, ' ', 'DocTypes', ' ', 'ID', ' ', '', '', 11, null, null, null) ;

CALL ImportDocCLS(986000, 9860, ' ', 'MEASUREMENTCLS', ' ', 'ID', ' ', '', '', 60, null, null, null) ;

CALL ImportDocCLS(988000, 9880, ' ', 'FundsSource', ' ', 'ID', ' ', '', '', 80, null, null, null) ;

CALL ImportDocCLS(985200, 9852, ' ', 'InnerFinSource', ' ', 'ID', ' ', '', '', 52, null, null, null) ;

CALL ImportDocCLS(981300, 9813, ' ', 'NOTIFYTYPES', ' ', 'ID', ' ', '', '', 13, null, null, null) ;

CALL ImportDocCLS(984500, 9845, ' ', 'PAYSYMBOLCLS', ' ', 'ID', ' ', '', '', 45, null, null, null) ;

CALL ImportDocCLS(980400, 9804, ' ', 'KVR', ' ', 'ID', ' ', '', '', 4, null, null, null) ;

CALL ImportDocCLS(980300, 9803, ' ', 'KVSR', ' ', 'ID', ' ', '', '', 3, null, null, null) ;

CALL ImportDocCLS(980900, 9809, ' ', 'KD', ' ', 'ID', ' ', '', '', 9, null, null, null) ;

CALL ImportDocCLS(984700, 9847, ' ', 'TYPEOPERATIONCLS', ' ', 'ID', ' ', '', '', 47, null, null, null) ;

CALL ImportDocCLS(986800, 9868, ' ', 'KESR', ' ', 'ID', ' ', '', '', 68, null, null, null) ;

CALL ImportDocCLS(987900, 9879, ' ', 'TargetCls', ' ', 'ID', ' ', '', '', 79, null, null, null) ;

CALL ImportDocCLS(985100, 9851, ' ', 'Error', ' ', 'ID', ' ', '', '', 51, null, null, null) ;

CALL ImportDocCLS(982100, 9821, ' ', 'ACC_CLS', ' ', 'ID', ' ', '', '', 21, null, null, null) ;

CALL ImportDocCLS(981400, 9814, ' ', 'KSHK', ' ', 'ID', ' ', '', '', 14, null, null, null) ;

CALL ImportDocCLS(980200, 9802, ' ', 'kfsr', ' ', 'ID', ' ', '', '', 2, null, null, null) ;

CALL ImportDocCLS(980500, 9805, ' ', 'KCSR', ' ', 'ID', ' ', '', '', 5, null, null, null) ;

CALL ImportDocCLS(984100, 9841, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', '', '', 41, null, null, null) ;

CALL ImportDocCLS(981500, 9815, ' ', 'VALUECLS', ' ', 'ID', ' ', '', '', 15, null, null, null) ;

CALL ImportDocCLS(982800, 9828, ' ', 'FACT', ' ', 'ID', ' ', '', '', 28, null, null, null) ;

CALL ImportDocCLS(984800, 9848, ' ', 'PAYDESTINATIONCLS', ' ', 'ID', ' ', '', '', 48, null, null, null) ;

CALL ImportDocCLS(986900, 9869, ' ', 'DirectionCLS', ' ', 'ID', ' ', '', '', 69, null, null, null) ;

CALL ImportDocCLS(986200, 9862, ' ', 'OKATO', ' ', 'ID', ' ', '', '', 62, null, null, null) ;

CALL ImportDocCLS(988200, 9882, ' ', 'OKOPF', ' ', 'ID', ' ', '', '', 82, null, null, null) ;

CALL ImportDocCLS(988100, 9881, ' ', 'OKFS', ' ', 'ID', ' ', '', '', 81, null, null, null) ;

CALL ImportDocCLS(981600, 9816, ' ', 'MeansCLS', ' ', 'ID', ' ', '', '', 16, null, null, null) ;

CALL ImportDocCLS(985900, 9859, ' ', 'DepartmentCLS', ' ', 'ID', ' ', '', '', 59, null, null, null) ;

CALL ImportDocCLS(986500, 9865, ' ', 'BuhAccPlan', ' ', 'ID', ' ', '', '', 65, null, null, null) ;

CALL ImportDocCLS(986100, 9861, ' ', 'TenderObjects', ' ', 'ID', ' ', '', '', 61, null, null, null) ;

CALL ImportDocCLS(985000, 9850, ' ', 'RejectCLS', ' ', 'ID', ' ', '', '', 50, null, null, null) ;

CALL ImportDocCLS(987000, 9870, ' ', 'ProgramCode', ' ', 'ID', ' ', '', '', 70, null, null, null) ;

CALL ImportDocCLS(981200, 9812, ' ', 'RegionCLS', ' ', 'ID', ' ', '', '', 12, null, null, null) ;

CALL ImportDocCLS(982600, 9826, ' ', 'BUDGETACCOUNTS', ' ', 'ID', ' ', '', '', 26, null, null, null) ;

CALL ImportDocCLS(981700, 9817, ' ', 'REFCLS', ' ', 'ID', ' ', '', '', 17, null, null, null) ;

CALL ImportDocCLS(981000, 9810, ' ', 'SubKD', ' ', 'ID', ' ', '', '', 10, null, null, null) ;

CALL ImportDocCLS(980600, 9806, ' ', 'SUBKCSR', ' ', 'ID', ' ', '', '', 6, null, null, null) ;

CALL ImportDocCLS(980800, 9808, ' ', 'KESRSubCode', ' ', 'ID', ' ', '', '', 8, null, null, null) ;

CALL ImportDocCLS(986300, 9863, ' ', 'COLLATERALTYPE', ' ', 'ID', ' ', '', '', 63, null, null, null) ;

CALL ImportDocCLS(982000, 9820, ' ', 'ORG_CLS', ' ', 'ID', ' ', '', '', 20, null, null, null) ;

CALL ImportDocCLS(983400, 9834, ' ', 'ReportType', ' ', 'ID', ' ', '', '', 34, null, null, null) ;

CALL ImportDocCLS(985300, 9853, ' ', 'REESTRTYPE', ' ', 'ID', ' ', '', '', 53, null, null, null) ;

CALL ImportDocCLS(984900, 9849, ' ', 'MEANSTYPE', ' ', 'ID', ' ', '', '', 49, null, null, null) ;

CALL ImportDocCLS(982700, 9827, ' ', 'FinType', ' ', 'ID', ' ', '', '', 27, null, null, null) ;

CALL ImportDocCLS(984400, 9844, ' ', 'Org_AccDefaults', ' ', 'ID', ' ', '', '', 44, null, null, null) ;

CALL ImportDocCLS(960100, 9601, ' ', 'ORGANIZATIONS', ' ', 'ID', ' ', '', '', 1000, null, null, null) ;

CALL ImportDocCLS(960200, 9602, ' ', 'ORG_ACCOUNTS', ' ', 'ID', ' ', '', '', 1001, null, null, null) ;

CALL ImportDocCLS(960400, 9604, ' ', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', '', '', 1003, null, null, null) ;

CALL ImportDocCLS(960300, 9603, ' ', 'BANKS', ' ', 'ID', ' ', '', '', 1002, null, null, null) ;

CALL ImportDocCLS(987100, 9871, ' ', 'BuhOperationCls', ' ', 'Id', ' ', '', '', 71, null, null, null) ;

CALL ImportDocCLS(987800, 9878, ' ', 'budgets_s', ' ', 'id', ' ', '', '', 78, null, null, null) ;

CALL ImportDocCLS(991400, 9914, '', 'DATAPACKETTYPES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991401, 9914, '', 'DATAPACKETCONTENT', ' ', 'ID', ' ', 'DATAPACKETTYPE', '', 0, null, null, null) ;

CALL ImportDocCLS(991500, 9915, '', 'UNLOCKDATES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991501, 9915, '', 'UNLOCKDATES', ' ', 'ID', ' ', 'ID', '', 0, null, null, null) ;

CALL ImportDocCLS(20001, 200, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(30000, 300, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(30001, 300, '', ' ', ' ', ' ', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190000, 1900, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(190001, 1900, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(220000, 2200, '', 'BUDNOTIFY', ' ', 'id', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(220001, 2200, '', 'BUDGETDATA', ' ', 'id', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(991300, 9913, '', 'INTERFACES', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991301, 9913, '', 'Permissions', ' ', 'ID', ' ', 'INTERFACEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(991302, 9913, '', 'LinkType', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991303, 9913, ' ', ' ', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(490200, 4902, '', 'DATAPACKET', ' ', 'ID', ' ', '', ' ', 0, null, null, 526) ;

CALL ImportDocCLS(250400, 2504, '', 'AGREEMENTS', 'AGREEMENTS', 'ID', 'ID', '', '', 0, null, null, 314) ;

CALL ImportDocCLS(300100, 3001, '', 'TenderCaption', ' ', 'ID', ' ', '', '', 0, null, null, 230) ;

CALL ImportDocCLS(250401, 2504, '  ', 'AGREEMENTSTEPS', 'AGREEMENTSTEPS', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(250402, 2504, '   ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'AGREEMENTREF', 'AGREEMENTREF', 0, null, null, 314) ;

CALL ImportDocCLS(250403, 2504, '  ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, null) ;

CALL ImportDocCLS(300600, 3006, '', 'TENDERCAPTION', ' ', 'ID', ' ', '', '', 0, null, null, 241) ;

CALL ImportDocCLS(250102, 2501, '  . ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 305) ;

CALL ImportDocCLS(70202, 702, '', 'PAYDOCEXCHANGE', ' ', 'ID', ' ', 'PAYDOCREF', '', 0, null, null, null) ;

CALL ImportDocCLS(170101, 1701, '', 'REQUESTSPAYMENTS', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(20900, 209, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 274) ;

CALL ImportDocCLS(300601, 3006, '  ', 'TENDERPRODUCT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 241) ;

CALL ImportDocCLS(300602, 3006, '   ', 'TENDERCONTACTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300300, 3003, '', 'TenderResultCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(300101, 3001, ' ', 'TenderProduct', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 230) ;

CALL ImportDocCLS(300102, 3001, ' ', 'TenderLot', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300103, 3001, '   ', 'TENDERSOURCEORG', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300104, 3001, '   ', 'TENDERYARDSTICKS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300105, 3001, '   ', 'TENDERYARDSTICKS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300106, 3001, ' ', 'TENDERCONTACTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300107, 3001, '   ', 'TENDERSUPPLEMENTS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(300108, 3001, ',  ', 'TENDERSUPDOCUMENT', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(370100, 3701, '', 'TenderObjects', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(520101, 5201, '', 'WritExecutionDetail', 'WritExecutionDetail', 'id', 'id', 'RecordIndex', '', 0, null, null, 556) ;

CALL ImportDocCLS(20901, 209, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 274) ;

CALL ImportDocCLS(21000, 210, '', 'BUDNOTIFY', ' ', 'ID', ' ', '', '', 0, null, null, 252) ;

CALL ImportDocCLS(21001, 210, ', ', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 252) ;

CALL ImportDocCLS(21002, 210, '', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 253) ;

CALL ImportDocCLS(991800, 9918, '', 'USERGENERATOR', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(991801, 9918, '', 'USERGENERATORFIELDS', ' ', 'ID', ' ', 'GENREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992702, 9927, '   ', 'REMOTEINPUTRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(21202, 212, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 276) ;

CALL ImportDocCLS(990802, 9908, ' ', 'STATE_DOCSTATES', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(990803, 9908, '', 'STATE_JUMPS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(990804, 9908, '', 'STATE_ACTIONS', ' ', 'ID', ' ', 'DOCTYPEREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992703, 9927, '   ', 'REMOTECLIENTACCOUNT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(992000, 9920, '', 'BUHOPERATIONCLS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992001, 9920, '', 'BUHACCCORR', ' ', 'ID', ' ', 'BUHOPERATIONCLS', '', 0, null, null, null) ;

CALL ImportDocCLS(992100, 9921, '', 'BUDGETS_S', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992101, 9921, ' ', 'FACIALACC_CLS', ' ', 'ID', ' ', 'BUDGETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(992102, 9921, ' ', 'DFACCOUNTSBUHTABLE', ' ', 'ID', ' ', 'BUDGETREF', '', 0, null, null, null) ;

CALL ImportDocCLS(989000, 9890, ' ', 'BudAllocationCls', ' ', 'id', ' ', '', '', 90, null, null, null) ;

CALL ImportDocCLS(989100, 9891, ' ', 'PayPromiseCls', ' ', 'id', ' ', '', '', 91, null, null, null) ;

CALL ImportDocCLS(550300, 5503, '', 'ReplacementClsCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(550301, 5503, '   ', 'ReplacementClsDetail', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(550302, 5503, ' ', 'ReplacementClsDetailInfo', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(250302, 2503, ' ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'EXECUTIONREF', '', 0, null, null, 308) ;

CALL ImportDocCLS(181400, 1814, '', 'BANKEXCH_LS_KB', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(180900, 1809, '', 'BANKEXCH_SUBSTITUTION', 'BANKEXCH_SUBSTITUTION', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181500, 1815, '', 'BANKEXCH_KO_SALDO', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992900, 9929, '', 'BudStruct', 'BudStruct', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992201, 9922, '', 'ARCHIVEDOCPARAMS', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(992400, 9924, '', 'SIGNS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(480101, 4801, '', 'GeneralDocsDetail', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992502, 9925, '', 'CARDSDETAIL_KESR', ' ', 'ID', ' ', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(250203, 2502, ' ', 'ESTIMATE', 'ESTIMATE', 'ID', 'ID', 'RECORDINDEX', 'RECORDINDEX', 0, null, null, 304) ;

CALL ImportDocCLS(250404, 2504, ' ', 'EXECUTIONDOCUMENTSCAPTION', 'EXECUTIONDOCUMENTSCAPTION', 'ID', 'ID', '', '', 0, null, null, null) ;

CALL ImportDocCLS(520102, 5201, '2', 'WritExecutionNotify', 'WritExecutionNotify', 'id', 'id', 'RecordIndex', '', 0, null, null, null) ;

CALL ImportDocCLS(989200, 9892, ' ', 'ArchiveDocType', ' ', 'id', ' ', '', '', 92, null, null, null) ;

CALL ImportDocCLS(480100, 4801, '', 'GeneralDocuments', ' ', 'ID', ' ', '', '', 0, null, null, 528) ;

CALL ImportDocCLS(992600, 9926, '', 'WritNotifyCls', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992601, 9926, '', 'WRITNOTIFYCLSDETAIL', ' ', 'ID', ' ', 'RECORDINDEX', ' ', 0, null, null, null) ;

CALL ImportDocCLS(992602, 9926, ' ', 'WritNotifyClsPart', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(31600, 316, '', 'ManagerBid', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(20902, 209, '2', 'BUDGETDATA', ' ', 'ID', ' ', 'RECORDINDEX', '', 0, null, null, 274) ;

CALL ImportDocCLS(992704, 9927, '  + /', 'DUALRIGHTS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992705, 9927, ' ', 'REMOTEEDSRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(992706, 9927, ' ', 'REMOTEEDSRIGHT', ' ', 'ID', ' ', 'REMOTECLIENT', '', 0, null, null, null) ;

CALL ImportDocCLS(990400, 9904, '', 'CONTACTPERSONS', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(181601, 1816, '', 'FacialFinCaption', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992707, 9927, '', 'SIGNCERTIFICATE', ' ', 'ID', ' ', '', '', 0, null, null, null) ;

CALL ImportDocCLS(992708, 9927, '  ', 'SIGNDOCUMENTSGROUP', ' ', 'ID', ' ', 'CLIENTREF', '', 0, null, null, null) ;

CALL ImportDocCLS(510100, 5101, '', 'StoredAttributesCaption', 'StoredAttributesCaption', 'id', 'id', '', '', 0, null, null, null) ;

CALL ImportDocCLS(510101, 5101, '', 'StoredAttributesDetail', 'StoredAttributesDetail', 'id', 'id', 'RecordIndex', 'RecordIndex', 0, null, null, null) ;

CALL ImportDocCLS(250405, 2504, ' ', 'PAYMENTSCHEDULE', 'PAYMENTSCHEDULE', 'ID', 'ID', 'RECORDINDEX', '', 0, null, null, null) ;

CALL ImportDocCLS(970200, 9702, ' ', 'AnalyticalGroupIFS', 'AnalyticalGroupIFS', 'ID', 'ID', '', '', 102, null, null, null) ;

CALL ImportDocCLS(970100, 9701, ' ', 'AnalyticalGroupKD', 'AnalyticalGroupKD', 'ID', 'ID', '', '', 101, null, null, null) ;

DROP PROCEDURE ImportDocCLS
/

COMMIT WORK
/


CREATE OR REPLACE PROCEDURE ImportField (
   ID_                NUMBER,
   NAME_              VARCHAR2,
   ITFFIELDNAME_      VARCHAR2,
   NOTE_              VARCHAR2,
   TEMPLATEFIELD_     VARCHAR2,
   ISBUDGET_          NUMBER,
   DOCTYPEREF_        NUMBER,
   DETAILNUMBER_      NUMBER,
   ONLYREAD_          NUMBER,
   ReportFieldName_   VARCHAR2,
   KIND_              NUMBER,
   FIELDINFOREF_      NUMBER,
   CONTAINERREF_      NUMBER, 
   ATTRFIELDKIND_     NUMBER
) IS
   IDExists$   NUMBER (10);
BEGIN
   SELECT COUNT (ID)
     INTO IDExists$
     FROM DocumentFields
    WHERE (ID = ID_);

   IF (IDExists$ <> 0) THEN
      UPDATE DocumentFields
         SET NAME = NAME_,
             ITFFIELDNAME = ITFFIELDNAME_,
             NOTE = NOTE_,
             TEMPLATEFIELD = TEMPLATEFIELD_,
             ISBUDGET = ISBUDGET_,
             DOCTYPEREF = DOCTYPEREF_,
             DETAILNUMBER = DETAILNUMBER_,
             ONLYREAD = ONLYREAD_,
             ReportFieldName = ReportFieldName_,
                               FIELDINFOREF = FIELDINFOREF_, 
             CONTAINERREF = CONTAINERREF_, 
             ATTRFIELDKIND = ATTRFIELDKIND_
       WHERE (ID = ID_)
         AND NOT (
                      (
                          (
                           (NAME IS NOT NULL AND NAME_ IS NOT NULL) AND
                           (UPPER (NAME) = UPPER (NAME_))
                          )
                       OR (NAME IS NULL AND NAME_ IS NULL)
                      )

                  AND (
                          (
                           (ITFFIELDNAME_ IS NOT NULL AND ITFFIELDNAME IS NOT NULL) AND
                           (UPPER (ITFFIELDNAME_) = UPPER (ITFFIELDNAME))
                          )
                       OR (ITFFIELDNAME_ IS NULL AND ITFFIELDNAME IS NULL)
                      )
                      
                  AND (
                          (
                           (NOTE IS NOT NULL AND NOTE_ IS NOT NULL) AND
                           (UPPER (NOTE) = UPPER (NOTE_))
                          )
                       OR (NOTE IS NULL AND NOTE_ IS NULL)
                      )
                  AND (UPPER (TEMPLATEFIELD) = UPPER (TEMPLATEFIELD_))
                  AND (
                          (
                           (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                           (ISBUDGET = ISBUDGET_)
                          )
                       OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                      )
                  AND (
                          (
                           (FIELDINFOREF IS NOT NULL AND FIELDINFOREF_ IS NOT NULL) AND
                           (FIELDINFOREF = FIELDINFOREF_)
                          )
                       OR (FIELDINFOREF IS NULL AND FIELDINFOREF_ IS NULL)
                      )
                  AND (
                          (
                           (CONTAINERREF IS NOT NULL AND CONTAINERREF_ IS NOT NULL) AND
                           (CONTAINERREF = CONTAINERREF_)
                          )
                       OR (CONTAINERREF IS NULL AND CONTAINERREF_ IS NULL)
                      )   
                  AND (
                          (
                           (ATTRFIELDKIND IS NOT NULL AND ATTRFIELDKIND_ IS NOT NULL) AND
                           (ATTRFIELDKIND = ATTRFIELDKIND_)
                          )
                       OR (ATTRFIELDKIND IS NULL AND ATTRFIELDKIND_ IS NULL)
                      )                                            
                  AND (DOCTYPEREF = DOCTYPEREF_)
                  AND (DETAILNUMBER = DETAILNUMBER_)
                  AND (ONLYREAD = ONLYREAD_)
                  AND (
                          (
                           (ReportFieldName IS NOT NULL AND ReportFieldName_ IS NOT NULL) AND
                           (UPPER (ReportFieldName) = UPPER (ReportFieldName_))
                          )
                       OR (ReportFieldName IS NULL AND ReportFieldName_ IS NULL)
                      )
                 );
   ELSE
      INSERT INTO DocumentFields
                  (ID, NAME, ITFFIELDNAME, NOTE, TEMPLATEFIELD,
                   ISBUDGET, DOCTYPEREF, DETAILNUMBER, ONLYREAD, ReportFieldName, FIELDINFOREF, CONTAINERREF, ATTRFIELDKIND
                  )
           VALUES (ID_, NAME_, ITFFIELDNAME_, NOTE_, TEMPLATEFIELD_,
                   ISBUDGET_, DOCTYPEREF_, DETAILNUMBER_, ONLYREAD_, ReportFieldName_, FIELDINFOREF_, CONTAINERREF_, ATTRFIELDKIND_
                  );
   END IF;

   FOR tab_rec IN (
                   SELECT ID
                     FROM DocumentFields
                    WHERE (ID <> ID_)
                      AND (DOCTYPEREF = DOCTYPEREF_)
                      AND (
                              (
                               (ISBUDGET IS NOT NULL AND ISBUDGET_ IS NOT NULL) AND
                               (ISBUDGET = ISBUDGET_)
                              )
                           OR (ISBUDGET IS NULL AND ISBUDGET_ IS NULL)
                          )
                      AND (DETAILNUMBER = DETAILNUMBER_)
              AND ( /*      ,       ,       */
                            (
                             ((ITFFIELDNAME_ IS NULL)or(ITFFIELDNAME_=' '))
                 and not((TEMPLATEFIELD_ IS NULL)or(TEMPLATEFIELD_=' '))
                 and(TEMPLATEFIELD is NOT null) and (UPPER(TEMPLATEFIELD)=UPPER(TEMPLATEFIELD_))
                            )
                    or (
                        not ((ITFFIELDNAME_ IS NULL) or (ITFFIELDNAME_=' '))
                                and (ITFFIELDNAME IS NOT NULL) and (UPPER(ITFFIELDNAME)=UPPER(ITFFIELDNAME_)))
                            )
                       )
   LOOP
      UPDATE State_OpenFields
         SET DOCFIELDREF = ID_
       WHERE (DOCFIELDREF = tab_rec.ID);

      UPDATE DOCLOCKFIELDS
         SET FIELDREF = ID_
       WHERE (FIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET PARENTFIELDREF = ID_
      WHERE (PARENTFIELDREF = tab_rec.ID);

      UPDATE staticlinks
         SET CHILDFIELDREF = ID_
      WHERE (CHILDFIELDREF = tab_rec.ID);

      DELETE FROM DocumentFields
            WHERE (ID = tab_rec.ID);
   END LOOP;
END;
/

CREATE OR REPLACE PROCEDURE DeleteFields (ID$ NUMBER) IS
BEGIN
  DELETE FROM State_OpenFields
  WHERE (docfieldref = ID$);
  DELETE FROM DOCLOCKFIELDS
  WHERE (fieldref = ID$);

  DELETE FROM STATE_JUMPCONTROL
  WHERE STATICLINKREF IN(SELECT ID FROM staticlinks
                           WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$));
  DELETE FROM staticlinks
  WHERE (PARENTFIELDREF=ID$)OR(CHILDFIELDREF=ID$);
  
  DELETE FROM DOCUMENTTEMPLATEFIELDS
  WHERE (FIELDS=ID$);

  DELETE FROM DocumentFields
  WHERE (id = ID$);
END;
/

CREATE OR REPLACE PROCEDURE INSERTCONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER,
  NOTE_          VARCHAR2,
  VARCHARVALUE_  VARCHAR2,
  DOUBLEVALUE_   NUMBER,
  INTVALUE_      INTEGER,
  EDITDOCCODE_   INTEGER
) IS
  IDEXISTS$ NUMBER;
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM IntConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO INTCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,INTVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE INTCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 8) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM VarcharConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO VARCHARCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,VARCHARVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE VARCHARCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;    
  END IF;

  IF (CONSTTYPE_ = 5) THEN
    SELECT COUNT (PROGINDEX)
    INTO IDExists$
    FROM RealConst
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);

    IF (IDExists$ = 0) THEN
      INSERT INTO REALCONST
        (PROGINDEX,CONSTINDEX,CONSTVALUE,NOTE,EDITDOCCODE)
      VALUES
        (PROGINDEX_,CONSTINDEX_,DOUBLEVALUE_,NOTE_,EDITDOCCODE_);
    ELSE 
      UPDATE REALCONST SET
        NOTE = NOTE_,
        EDITDOCCODE = EDITDOCCODE_
      WHERE (PROGINDEX=PROGINDEX_) AND (CONSTINDEX=CONSTINDEX_);
    END IF;   
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DELETECONST (
  PROGINDEX_     NUMBER,
  CONSTINDEX_    NUMBER,
  CONSTTYPE_     NUMBER
) IS
BEGIN
  IF (CONSTTYPE_ = 3) THEN
    UPDATE IntConst
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
  IF (CONSTTYPE_ = 8) THEN
    UPDATE VARCHARCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_); 
  END IF;
  IF (CONSTTYPE_ = 5) THEN
    UPDATE REALCONST
      SET CloseDate = systimestamp
    WHERE (PROGINDEX = PROGINDEX_) AND (CONSTINDEX = CONSTINDEX_);
  END IF;
END;
/

--       
ALTER TRIGGER TR_INTCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 DISABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 DISABLE
/

--     
CALL DeleteFields(20901138) ;

--    , (1)
CALL ImportField(10111012, '', 'KESR', '', ' ', 1, 101, 1, 0, '', 0, 17827, 0, 0) ;

CALL ImportField(10111019, ' ', 'SUBKESR', ' ', ' ', 1, 101, 1, 0, '', 0, 17828, 0, 0) ;

CALL ImportField(10111022, ' . ', 'FINTYPECode', ' . ', ' ', 1, 101, 1, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(10111188, ' .  ()', 'FINTYPE', ' . ', ' ', 1, 101, 1, 0, '', 0, 17833, 0, 0) ;

CALL ImportField(10112049, '', 'KESR', '', ' ', 1, 101, 2, 0, '', 0, 17827, 0, 0) ;

CALL ImportField(10112054, '', 'SUBKESR', '', ' ', 1, 101, 2, 0, '', 0, 17828, 0, 0) ;

CALL ImportField(10112059, ' . ', 'FINTYPECode', ' . ', ' ', 1, 101, 2, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(10112219, ' .  ()', 'FINTYPE', ' . ', ' ', 1, 101, 2, 0, '', 0, 17833, 0, 0) ;

CALL ImportField(10114111, '', 'KESR', '', ' ', 1, 101, 4, 0, '', 0, 17827, 0, 0) ;

CALL ImportField(10114116, '', 'SUBKESR', '', ' ', 1, 101, 4, 0, '', 0, 17828, 0, 0) ;

CALL ImportField(10114121, ' . ', 'FINTYPECode', ' . ', ' ', 1, 101, 4, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(10114221, ' .  ()', 'FINTYPE', ' . ', ' ', 1, 101, 4, 0, '', 0, 17833, 0, 0) ;

--    (), (1)
CALL ImportField(20111007, '', 'Kesr', '', 'DestKesr', 1, 201, 1, 0, '', 0, 17415, 0, 0) ;

CALL ImportField(20111009, ' ', 'SubKesr', '', 'DestSubKesr', 1, 201, 1, 0, '', 0, 17416, 0, 0) ;

--  (), (1)
CALL ImportField(20211032, '', 'KESR', '', 'DestKesr', 1, 202, 1, 0, '', 0, 17415, 0, 0) ;

CALL ImportField(20211067, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 202, 1, 0, '', 0, 17416, 0, 0) ;

--   (), (1)
CALL ImportField(20311032, '', 'KESR', '', 'DestKesr', 1, 203, 1, 0, '', 0, 17415, 0, 0) ;

CALL ImportField(20311067, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 203, 1, 0, '', 0, 17416, 0, 0) ;

--  , , (1)
CALL ImportField(20411032, '', 'KESR', '', 'DestKesr', 1, 204, 1, 0, '', 0, 17415, 0, 0) ;

CALL ImportField(20411067, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 204, 1, 0, '', 0, 17416, 0, 0) ;

-- , (1)
CALL ImportField(20511033, '', 'KESR', '', 'DestKesr', 1, 205, 1, 0, '', 0, 17415, 0, 0) ;

CALL ImportField(20511065, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 205, 1, 0, '', 0, 17416, 0, 0) ;

--    (), (1)
CALL ImportField(20611033, '', 'KESR', '', 'DestKesr', 1, 206, 1, 0, '', 0, 17415, 0, 0) ;

CALL ImportField(20611068, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 206, 1, 0, '', 0, 17416, 0, 0) ;

--   , (1)
CALL ImportField(20711033, '', 'KESR', '', 'DestKesr', 1, 207, 1, 0, '', 0, 17415, 0, 0) ;

CALL ImportField(20711068, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 207, 1, 0, '', 0, 17416, 0, 0) ;

--    , (1)
CALL ImportField(20811033, '', 'KESR', '', 'DestKesr', 1, 208, 1, 0, '', 0, 17415, 0, 0) ;

CALL ImportField(20811068, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 208, 1, 0, '', 0, 17416, 0, 0) ;

--  , (1)
CALL ImportField(20911017, '()', 'KESR', '', 'DestKesr', 1, 209, 1, 1, '', 0, 17415, 0, 0) ;

CALL ImportField(20911027, ' ', 'SUBKESR', ' ', 'DestSubkesr', 1, 209, 1, 1, '', 0, 17416, 0, 0) ;

CALL ImportField(20912017, '()', 'KESR', '', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(20912027, ' ', 'SUBKESR', ' ', ' ', 1, 209, 2, 0, '', 0, null, 0, 0) ;

--  , (1)
CALL ImportField(21011017, '()', 'KESR', '', 'DestKesr', 1, 210, 1, 0, '', 0, 17415, 0, 0) ;

CALL ImportField(21011029, ' ', 'SUBKESR', ' ', 'DestSubkesr', 1, 210, 1, 0, '', 0, 17416, 0, 0) ;

CALL ImportField(21012015, '()', 'KESR', '', 'DestKesr', 1, 210, 2, 0, '', 0, 17415, 0, 0) ;

CALL ImportField(21012016, ' ()', 'KESRCORR', ' ()', 'KESRCORR', 1, 210, 2, 1, '', 0, 17461, 0, 0) ;

CALL ImportField(21012043, ' ', 'SUBKESR', ' ', 'DestSubkesr', 1, 210, 2, 0, '', 0, 17416, 0, 0) ;

--  , (1)
CALL ImportField(21111019, '()', 'KESR', '', 'DestKesr', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21111029, ' ', 'SUBKESR', ' ', 'DestSubkesr', 1, 211, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21112016, '()', 'KESR', '', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21112026, ' ', 'SUBKESR', ' ', ' ', 1, 211, 2, 0, '', 0, null, 0, 0) ;

--   , , (1)
CALL ImportField(21211019, '()', 'KESR', '', 'DestKesr', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21211029, ' ', 'SUBKESR', ' ', 'DestSubkesr', 1, 212, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(21212016, '()', 'KESR', '', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(21212026, ' ', 'SUBKESR', ' ', ' ', 1, 212, 2, 0, '', 0, null, 0, 0) ;

--  , (1)
CALL ImportField(30111005, ' .( .)', 'SourceKESR', ' ', 'SourceKESR', 1, 301, 1, 0, ',', 0, 18868, 0, 0) ;

CALL ImportField(30111009, '  .', 'SourceSubKESR', ' ', 'SourceSubKESR', 1, 301, 1, 0, ',', 0, 18889, 0, 0) ;

CALL ImportField(30111017, ' -( -)', 'DestKESR', ' ', 'DestKESR', 1, 301, 1, 0, 'DestKESR,', 0, 18871, 0, 0) ;

CALL ImportField(30111021, '  -', 'DestSubKESR', ' ', 'DestSubKESR', 1, 301, 1, 0, 'DestSubKESR,', 0, 18898, 0, 0) ;

--   \, (1)
CALL ImportField(30211001, ' ', 'SOURCESUBKESR', '', 'SOURCESUBKESR', 1, 302, 1, 0, '', 0, 18889, 0, 0) ;

CALL ImportField(30211004, '', 'SOURCEKESR', '', 'SourceKESR', 1, 302, 1, 0, '', 0, 18868, 0, 0) ;

--  (), (1)
CALL ImportField(30311017, '', 'DESTKESR', '', 'DESTKESR', 1, 303, 1, 0, '', 0, 18871, 0, 0) ;

CALL ImportField(30311022, ' ', 'DestSubKESR', ' ', 'DestSubKESR', 1, 303, 1, 0, '', 0, 18898, 0, 0) ;

--   , (1)
CALL ImportField(30411014, '', 'SOURCEKESR', '', 'SourceKESR', 1, 304, 1, 0, '', 0, 18868, 0, 0) ;

CALL ImportField(30411016, ' ', 'SOURCESUBKESR', '', 'SOURCESUBKESR', 1, 304, 1, 0, '', 0, 18889, 0, 0) ;

--   \, (1)
CALL ImportField(30511014, '', 'DESTKESR', ' ', 'DestKESR', 1, 305, 1, 0, '', 0, 18871, 0, 0) ;

CALL ImportField(30511018, ' ', 'DestSubKESR', ' ', 'DestSUBKESR', 1, 305, 1, 0, '', 0, 18898, 0, 0) ;

--   , (1)
CALL ImportField(30611022, '', 'DESTKESR', '', 'DestKESR', 1, 306, 1, 0, '', 0, 18871, 0, 0) ;

CALL ImportField(30611039, ' ', 'DestSubKESR', ' ', 'DestSUBKESR', 1, 306, 1, 0, '', 0, 18898, 0, 0) ;

--  , (1)
CALL ImportField(30811027, '  ', 'DestSubKESR', '  -', 'DestSUBKESR', 1, 308, 1, 0, '', 0, 18898, 0, 0) ;

CALL ImportField(30811045, ' ( )', 'SOURCEKESR', ' .( .)', 'SourceKESR', 1, 308, 1, 0, ',', 0, 18868, 0, 0) ;

CALL ImportField(30811052, '  ', 'SourceSubKESR', '  .', 'SourceSUBKESR', 1, 308, 1, 0, ',', 0, 18889, 0, 0) ;

--    , (1)
CALL ImportField(31111005, '', 'SOURCEKESR', '', 'SOURCEKESR', 1, 311, 1, 0, '', 0, 18868, 0, 0) ;

CALL ImportField(31111009, ' ', 'SourceSubKESR', ' ', 'SourceSubKESR', 1, 311, 1, 0, '', 0, 18889, 0, 0) ;

CALL ImportField(31111018, ' ', 'DESTKESR', ' ', 'DESTKESR', 1, 311, 1, 1, '', 0, 18871, 0, 0) ;

CALL ImportField(31111022, '  ', 'DestSubKESR', '  ', 'DestSubKESR', 1, 311, 1, 1, '', 0, 18898, 0, 0) ;

--     , (1)
CALL ImportField(31211017, '', 'DestKESR', ' ', 'DestKESR', 1, 312, 1, 0, '', 0, 18871, 0, 0) ;

CALL ImportField(31211021, ' ', 'DestSUBKESR', ' ', 'DestSUBKESR', 1, 312, 1, 0, '', 0, 18898, 0, 0) ;

CALL ImportField(31211035, ' ', 'SourceKESR', ' ', 'SourceKESR', 1, 312, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(31211039, ' ', 'SourceSUBKESR', ' ', 'SourceSUBKESR', 1, 312, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(31211043, ' .  ', ' ', ' .  ', 'SourceFINTYPECLS', 1, 312, 1, 1, '', 1, null, 0, 0) ;

--    , (1)
CALL ImportField(31411017, ' ', 'DestKESR', ' ', 'DestKESR', 1, 314, 1, 1, '', 0, 18871, 0, 0) ;

CALL ImportField(31411021, ' ', 'DestSUBKESR', ' ', 'DestSUBKESR', 1, 314, 1, 1, '', 0, 18898, 0, 0) ;

CALL ImportField(31411025, ' .  ', ' ', ' .  ', 'DestFINTYPECLS', 1, 314, 1, 1, '', 1, null, 0, 0) ;

CALL ImportField(31411035, '', 'SourceKESR', ' ', 'SourceKESR', 1, 314, 1, 0, '', 0, 18868, 0, 0) ;

CALL ImportField(31411039, ' ', 'SourceSUBKESR', ' ', 'SourceSUBKESR', 1, 314, 1, 0, '', 0, 18889, 0, 0) ;

--      , (1)
CALL ImportField(31511020, '', 'DESTKESR', '', 'DestKESR', 1, 315, 1, 0, '', 0, 18871, 0, 0) ;

CALL ImportField(31511031, ' ', 'DestSubKESR', ' ', 'DestSUBKESR', 1, 315, 1, 0, '', 0, 18898, 0, 0) ;

--   , (1)
CALL ImportField(32211027, '', 'SOURCEKESR', '', ' ', 1, 322, 1, 0, '', 0, 18868, 0, 0) ;

CALL ImportField(32211039, ' ', 'SourceSubKESR', ' ', ' ', 1, 322, 1, 0, '', 0, 18889, 0, 0) ;

--  , (1)
CALL ImportField(32311018, '', 'DESTKESR', '', 'DestKESR', 1, 323, 1, 0, '', 0, 18871, 0, 0) ;

CALL ImportField(32311031, ' ', 'DestSubKESR', ' ', 'DestSUBKESR', 1, 323, 1, 0, '', 0, 18898, 0, 0) ;

--  , (1)
CALL ImportField(32411076, '', 'DESTKESR', ' -', 'DestKESR', 1, 324, 1, 0, ',', 0, 18871, 0, 0) ;

CALL ImportField(32411081, ' ', 'DestSubKESR', '  -', 'DestSUBKESR', 1, 324, 1, 0, ',', 0, 18898, 0, 0) ;

--    , (1)
CALL ImportField(40114104, '', 'KESR', '', ' ', 1, 401, 4, 0, '', 0, 18151, 0, 0) ;

CALL ImportField(40116125, '', 'KESR', '', ' ', 1, 401, 6, 0, '', 0, 17827, 0, 0) ;

CALL ImportField(40116128, ' . ', 'FINTYPECode', ' . ', ' ', 1, 401, 6, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(40116139, '', 'SUBKESR', '', ' ', 1, 401, 6, 0, '', 0, 17828, 0, 0) ;

CALL ImportField(40116250, ' .  ()', 'FINTYPE', ' .  ()', ' ', 1, 401, 6, 1, ',', 0, 17833, 0, 0) ;

CALL ImportField(40110190, ' . ', 'FINTYPECode', ' . ', ' ', 1, 401, 10, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(40110196, '', 'KESR', '', ' ', 1, 401, 10, 0, '', 0, 17827, 0, 0) ;

CALL ImportField(40110202, '', 'SUBKESR', '', ' ', 1, 401, 10, 0, '', 0, 17828, 0, 0) ;

CALL ImportField(40110255, ' .  ()', 'FINTYPE', ' .  ()', ' ', 1, 401, 10, 1, ',', 0, 17833, 0, 0) ;

--   , (1)
CALL ImportField(50111042, '', 'KESR', '', ' ', 1, 501, 1, 0, '', 0, 17827, 0, 0) ;

CALL ImportField(50111045, '', 'SUBKESR', '', ' ', 1, 501, 1, 0, '', 0, 17828, 0, 0) ;

CALL ImportField(50111048, ' . ', 'FINTYPECODE', ' . ', ' ', 1, 501, 1, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(50111186, ' .  ()', 'FINTYPE', ' .  ()', ' ', 1, 501, 1, 1, '', 0, 17833, 0, 0) ;

CALL ImportField(50113078, '', 'KESR', '', ' ', 1, 501, 3, 0, '', 0, 17827, 0, 0) ;

CALL ImportField(50113081, '', 'SUBKESR', '', ' ', 1, 501, 3, 0, '', 0, 17828, 0, 0) ;

CALL ImportField(50113084, ' . ', 'FINTYPECODE', ' . ', ' ', 1, 501, 3, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(50113190, ' .  ()', 'FINTYPE', ' .  ()', ' ', 1, 501, 3, 1, '', 0, 17833, 0, 0) ;

--   , (1)
CALL ImportField(70111011, '', 'KESR', '', ' ', 1, 701, 1, 0, '', 0, 17827, 0, 0) ;

CALL ImportField(70111018, ' ', 'SUBKESR', ' ', ' ', 1, 701, 1, 0, '', 0, 17828, 0, 0) ;

CALL ImportField(70111021, ' . ', 'FINTYPECODE', ' . ', ' ', 1, 701, 1, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(70111072, ' . ', 'FINTYPE', ' . ', ' ', 1, 701, 1, 1, '', 0, 17833, 0, 0) ;

--  , (1)
CALL ImportField(70310008, '', 'KESR', '', ' ', 1, 703, 0, 0, '', 0, 17827, 0, 0) ;

CALL ImportField(70310015, ' ', 'SUBKESR', ' ', ' ', 1, 703, 0, 0, '', 0, 17828, 0, 0) ;

CALL ImportField(70310020, ' . ', 'FINTYPECode', ' . ', ' ', 1, 703, 0, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(70310054, ' . ', 'FINTYPE', ' . ', ' ', 1, 703, 0, 1, '', 0, 17833, 0, 0) ;

--  , (1)
CALL ImportField(80111023, '', 'KESR', '', 'KESR', 1, 801, 1, 0, '', 0, 18630, 0, 0) ;

CALL ImportField(80111040, '', 'SUBKESR', '', 'SUBKESR', 1, 801, 1, 0, '', 0, 18635, 0, 0) ;

--   (), (1)
CALL ImportField(80210010, '', 'KESR', '', ' ', 1, 802, 0, 0, '', 0, 18630, 0, 0) ;

CALL ImportField(80210017, '', 'SUBKESR', '', ' ', 1, 802, 0, 0, '', 0, 18635, 0, 0) ;

CALL ImportField(80210026, ' . ', 'FinTypeCode', ' . ', ' ', 1, 802, 0, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(80210041, ' .  ()', 'FinType', ' .  ()', ' ', 1, 802, 0, 1, '', 0, 18634, 0, 0) ;

--     , (1)
CALL ImportField(80311015, '', 'KESR', '', ' ', 1, 803, 1, 0, '', 0, 18630, 0, 0) ;

CALL ImportField(80311028, ' . ', 'FinTypeCode', ' . ', ' ', 1, 803, 1, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(80311029, '', 'SUBKESR', '', ' ', 1, 803, 1, 0, '', 0, 18635, 0, 0) ;

CALL ImportField(80311054, ' .  ()', 'FinType', ' .  ()', ' ', 1, 803, 1, 1, '', 0, 18634, 0, 0) ;

--  , (1)
CALL ImportField(120110061, ' . ', 'FinTypeCode', ' . ', ' ', 1, 1201, 0, 1, ',', 0, 36853, 0, 0) ;

CALL ImportField(120110062, ' . ', 'FinType_corrCode', ' . ', ' ', 1, 1201, 0, 1, '', 0, 36853, 0, 0) ;

CALL ImportField(120110068, '', 'SubKESR', '', ' ', 1, 1201, 0, 1, '', 0, 17387, 0, 0) ;

CALL ImportField(120110069, '', 'SubKESR_corr', '', ' ', 1, 1201, 0, 1, '', 0, 17388, 0, 0) ;

CALL ImportField(120110077, ' .  ()', 'FinType', ' . ', ' ', 1, 1201, 0, 1, ',', 0, 17381, 0, 0) ;

CALL ImportField(120110078, ' .  ()', 'FinType_corr', ' .  ()', ' ', 1, 1201, 0, 1, '', 0, 17382, 0, 0) ;

--  , (1)
CALL ImportField(150110007, '', 'KESR', '', ' ', 1, 1501, 0, 0, '', 0, 18383, 0, 0) ;

CALL ImportField(150110010, '', 'SUBKESR', '', ' ', 1, 1501, 0, 0, '', 0, 18384, 0, 0) ;

CALL ImportField(150110015, ' . ', 'FINTYPECODE', ' . ', ' ', 1, 1501, 0, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(150110054, ' .  ()', 'FINTYPE', ' . ', ' ', 1, 1501, 0, 1, ',', 0, 18387, 0, 0) ;

--  , (1)
CALL ImportField(160111025, '', 'KESR', '', 'KESR', 1, 1601, 1, 0, '', 0, 19024, 0, 0) ;

CALL ImportField(160111028, ' . ', 'FinTypeCode', ' . ', 'FinTypeCls', 1, 1601, 1, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(160111044, ' ', 'SubKESR', ' ', 'SubKESR', 1, 1601, 1, 0, '', 0, 19031, 0, 0) ;

CALL ImportField(160111087, ' .  ()', 'FinType', ' . ', 'FinTypeClsCode', 1, 1601, 1, 1, ',', 0, 19029, 0, 0) ;

-- . - , (1)
CALL ImportField(160210015, '', 'KESR', '', ' ', 1, 1602, 0, 0, '', 0, 19024, 0, 0) ;

CALL ImportField(160210022, ' ', 'SubKESR', ' ', ' ', 1, 1602, 0, 0, '', 0, 19031, 0, 0) ;

CALL ImportField(160210025, ' . ', 'FinTypeCode', ' . ', ' ', 1, 1602, 0, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(160210047, ' .  ()', 'FinType', ' . ', ' ', 1, 1602, 0, 1, ',', 0, 19029, 0, 0) ;

-- , (1)
CALL ImportField(170110021, ' . ', 'FINTYPECODE', ' . ', 'FINTYPE', 1, 1701, 0, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(170110029, '', 'KESR', '', 'KESR', 1, 1701, 0, 0, '', 0, 19131, 0, 0) ;

CALL ImportField(170110049, ' ', 'SUBKESR', '', 'SUBKESR', 1, 1701, 0, 0, '', 0, 19132, 0, 0) ;

CALL ImportField(170110095, ' .  ()', 'FINTYPE', ' . ', 'FINTYPEKEY', 1, 1701, 0, 1, ',', 0, 19141, 0, 0) ;

-- (), (1)
CALL ImportField(170210030, '', 'KESR', '', ' ', 1, 1702, 0, 0, '', 0, 19131, 0, 0) ;

CALL ImportField(170210043, '', 'SubKESR', '', ' ', 1, 1702, 0, 0, '', 0, 19132, 0, 0) ;

CALL ImportField(170210047, ' . ', 'FinTypeCode', ' . ', ' ', 1, 1702, 0, 0, ',', 0, 36853, 0, 0) ;

CALL ImportField(170210053, ' .  ()', 'FinType', ' . ', ' ', 1, 1702, 0, 1, ',', 0, 19141, 0, 0) ;

--   , (1)
CALL ImportField(181610007, '', 'KESR', '', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181610034, ' ', 'SubKESR', '', ' ', 1, 1816, 0, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611070, '', 'KESR', '', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(181611073, ' ', 'SubKESR', '', ' ', 1, 1816, 1, 0, '', 0, null, 0, 0) ;

--   (), (1)
CALL ImportField(190011036, '', '{("")}', '', ' ', 1, 1900, 1, 0, '', 0, null, 0, 0) ;

--  (), (1)
CALL ImportField(190111019, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 1901, 1, 0, '', 0, 17416, 0, 0) ;

CALL ImportField(190111092, '  ', 'TransfertClsCode', '  ', 'TransfertClsValue', 1, 1901, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(190111107, '', 'Kesr', '', 'DestKesr', 1, 1901, 1, 0, '', 0, 17415, 0, 0) ;

--    (), (1)
CALL ImportField(190211071, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 1902, 1, 0, '', 0, 17416, 0, 0) ;

CALL ImportField(190211105, '', 'Kesr', '', 'DestKesr', 1, 1902, 1, 0, '', 0, 17415, 0, 0) ;

--   (), (1)
CALL ImportField(190311070, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 1903, 1, 0, '', 0, 17416, 0, 0) ;

CALL ImportField(190311106, '', 'Kesr', '', 'DestKesr', 1, 1903, 1, 0, '', 0, 17415, 0, 0) ;

--    (), (1)
CALL ImportField(190611071, ' ', 'SUBKESR', ' ', 'DestSubKesr', 1, 1906, 1, 0, '', 0, 17416, 0, 0) ;

CALL ImportField(190611108, '', 'Kesr', '', 'DestKesr', 1, 1906, 1, 0, '', 0, 17415, 0, 0) ;

--   (), (1)
CALL ImportField(220011010, '', '{("")}', '', ' ', 1, 2200, 1, 0, '', 0, null, 0, 0) ;

--   (), (1)
CALL ImportField(220111080, '', 'Kesr', '', 'DestKesr', 1, 2201, 1, 0, '', 0, 17415, 0, 0) ;

--  , +(2)
CALL ImportField(250112004, '', 'KESR', '', 'KESR', 2, 2501, 2, 0, '', 0, 20226, 0, 0) ;

-- , +(2)
CALL ImportField(250212004, ' ', 'SubKESR', '', 'SubKESR', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250212029, '', 'KESR', '', 'KESR', 2, 2502, 2, 0, '', 0, null, 0, 0) ;

--   , +(2)
CALL ImportField(250312011, '', 'KESR', '', 'KESR', 2, 2503, 2, 0, '', 0, 20226, 0, 0) ;

CALL ImportField(250312035, ' ', 'SubKESR', '', 'SubKESR', 2, 2503, 2, 0, '', 0, 20244, 0, 0) ;

--  , +(2)
CALL ImportField(250412010, ' ', 'SubKESR', '', 'SubKESR', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250412036, '', 'KESR', '', 'KESR', 2, 2504, 2, 0, '', 0, null, 0, 0) ;

CALL ImportField(250415010, '', 'KESR', '', 'KESR', 2, 2504, 5, 0, '', 0, null, 0, 0) ;

--    , +(2)
CALL ImportField(300111008, '', 'SubKESR', '', 'SubKESR', 2, 3001, 1, 0, '', 0, 21039, 0, 0) ;

CALL ImportField(300111041, '', 'KESR', '', 'KESR', 2, 3001, 1, 0, '', 0, 21038, 0, 0) ;

CALL ImportField(300111045, ' . ', 'FinTypeCode', ' . ', 'FinType', 2, 3001, 1, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(300111097, ' .  ()', 'FinType', ' . ', 'FinTypeKey', 2, 3001, 1, 1, '', 0, 21114, 0, 0) ;

-- -, +(2)
CALL ImportField(300611008, '', 'KESR', '', 'KESR', 2, 3006, 1, 0, '', 0, 21038, 0, 0) ;

--  , +(2)
CALL ImportField(370110012, '', 'KESR', '', 'KESR', 2, 3701, 0, 0, '', 0, null, 0, 0) ;

--  , (1)
CALL ImportField(440110060, ' . ', 'FinTypeCode', ' . ', 'FINTYPE', 1, 4401, 0, 1, '', 0, 36853, 0, 0) ;

CALL ImportField(440111026, '', 'KESR', '', 'KESR', 1, 4401, 1, 1, '', 0, 21716, 0, 0) ;

CALL ImportField(440111067, ' .  ()', 'FinType', ' .  ()', 'FINTYPEKey', 1, 4401, 1, 1, '', 0, 36850, 0, 0) ;

--  ,, (1)
CALL ImportField(440311026, '', 'KESR', '', 'KESR', 1, 4403, 1, 1, '', 0, null, 0, 0) ;

CALL ImportField(440311062, ' ', 'SubKESR', ' ', ' ', 1, 4403, 1, 1, '', 0, null, 0, 0) ;

--  / , (1)
CALL ImportField(520111008, ' . ', 'FINTYPECode', ' . ', 'FINTYPE', 1, 5201, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(520111011, '', 'KESR', '', 'KESR', 1, 5201, 1, 0, '', 0, null, 0, 0) ;

CALL ImportField(520111061, ' . ()', 'FINTYPE', ' . ()', 'FINTYPEKey', 1, 5201, 1, 1, '', 0, null, 0, 0) ;

--    , (1)
CALL ImportField(550111058, '', 'KESR', '', 'KESR', 1, 5501, 1, 0, '', 0, 22919, 0, 0) ;

CALL ImportField(550111074, '', 'SubKesr', '', 'SubKESR', 1, 5501, 1, 0, '', 0, 22927, 0, 0) ;

--    , (1)
CALL ImportField(550211058, '', 'KESR', '', 'KESR', 1, 5502, 1, 0, '', 0, 22919, 0, 0) ;

CALL ImportField(550211074, '', 'SubKesr', '', 'SubKESR', 1, 5502, 1, 0, '', 0, 22927, 0, 0) ;

--  , (1)
CALL ImportField(960210011, ' . ', 'FINTYPE', ' . ', ' ', 1, 9602, 0, 0, '', 0, 17114, 0, 0) ;

--  , +(2)
CALL ImportField(984110016, ' . ', 'FINTYPE', ' . ', ' ', 2, 9841, 0, 0, '', 0, 17141, 0, 0) ;

CALL ImportField(984110023, '', 'KESR', '', ' ', 2, 9841, 0, 0, '', 0, 17140, 0, 0) ;

--  , (1)
CALL ImportField(986110012, '', 'KESR', '', ' ', 1, 9861, 0, 0, '', 0, 20702, 0, 0) ;

--  , +(2)
CALL ImportField(986510003, ' ', 'ECCLS', '', ' ', 2, 9865, 0, 0, '', 0, 21630, 0, 0) ;

-- , +(2)
CALL ImportField(987110012, ' ', 'BUHOPERATIONCLS', '', ' ', 2, 9871, 0, 0, '', 0, 21635, 0, 0) ;

CALL ImportField(987110021, '', 'ID', '', ' ', 2, 9871, 0, 0, '', 0, null, 0, 0) ;

--   , +(2)
CALL ImportField(988410021, '', 'TRANSFERKESR', '', ' ', 2, 9884, 0, 0, '', 0, 25339, 0, 0) ;

--  , (1)
CALL ImportField(990311029, ' .  ()', 'FinType', ' .  ()', 'FINTYPEKey', 1, 9903, 1, 0, '', 0, 17114, 0, 0) ;

CALL ImportField(990311098, ' . ', 'FinTypeCode', ' . ', 'FINTYPE', 1, 9903, 1, 0, '', 0, 36853, 0, 0) ;

CALL ImportField(990311102, '', 'ID', '', ' ', 1, 9903, 1, 0, '', 0, 17109, 0, 0) ;

CALL ImportField(990312046, '', 'KESR', '', ' ', 1, 9903, 2, 0, '', 0, 17140, 0, 0) ;

CALL ImportField(990312047, ' .  ()', 'FINTYPE', ' .  ()', 'FINTYPEKey', 1, 9903, 2, 0, '', 0, 17141, 0, 0) ;

CALL ImportField(990312101, ' . ', 'FinTypeCode', ' . ', 'FINTYPE', 1, 9903, 2, 0, '', 0, 36853, 0, 0) ;

--   , (1)
CALL ImportField(992111006, ' .  ()', 'FINTYPE', ' .  ()', ' ', 1, 9921, 1, 0, '', 0, 17141, 0, 0) ;

CALL ImportField(992111021, '', 'KESR', '', ' ', 1, 9921, 1, 0, '', 0, 17140, 0, 0) ;

--   , (1)
CALL ImportField(992512001, '', 'KESR', '', ' ', 1, 9925, 2, 0, '', 0, 22627, 0, 0) ;

--     , (1)
CALL ImportField(992910006, '', 'KESR', '', ' ', 1, 9929, 0, 0, '', 0, null, 0, 0) ;

--       
ALTER TRIGGER TR_INTCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_VARCHARCONST_BU_500 ENABLE
/

ALTER TRIGGER TR_REALCONST_BU_500 ENABLE
/

DROP PROCEDURE ImportField
/

/*      */
ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 DISABLE
/

Update TB_DocumentFields df
set documentcls=doctyperef*100+detailnumber
where (detailnumber<100)and(documentcls is null)
 and(exists(select dc.id from documentcls dc where id=df.doctyperef*100+df.detailnumber))
/

ALTER TRIGGER TR_DOCUMENTFIELDS_BU_500 ENABLE
/

DROP PROCEDURE DeleteFields
/

DROP PROCEDURE InsertConst
/

DROP PROCEDURE DELETECONST
/




CREATE OR REPLACE PROCEDURE DOCLOCK_IMPORT(
  NAME_              VARCHAR2,
  LOCKMASK_          NUMBER,
  DOCREF_            NUMBER,
  DETAILNUM_         NUMBER,
  RUNPOS_            NUMBER,
  LOCKACTION_        NUMBER,
  USERIGHTS_        NUMBER,
  FORMULA_           VARCHAR2,
  FORDELETE_         NUMBER,
  ISSYSTEM_          NUMBER,
  NOTE_              VARCHAR2,
  FORINSERT_         NUMBER,
  VALIDATEMESSAGE_ VARCHAR2,
  VALIDATELEVEL_   NUMBER,
  VALIDATEFILTER_  VARCHAR2,
  ISBUDGET_ NUMBER)
IS
  DOCLOCKID$ Number(10);
BEGIN
   BEGIN
     SELECT ID
     INTO DOCLOCKID$
     FROM DOCLOCK
     WHERE (DOCREF = DOCREF_) AND(DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       DOCLOCKID$ := NULL;  
   END;
   
   IF (DOCLOCKID$ is not null) THEN
     IF (ISSYSTEM_ = 3) THEN
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_,
         USERIGHTS = USERIGHTS_
       WHERE ID = DOCLOCKID$;  
     ELSE
       UPDATE DOCLOCK SET
         NAME = NAME_,
         LOCKMASK = LOCKMASK_,
         DOCREF = DOCREF_,
         DETAILNUM = DETAILNUM_,
         RUNPOS = RUNPOS_,
         LOCKACTION = LOCKACTION_,
         FORMULA = FORMULA_,
         FORDELETE = FORDELETE_,
         ISSYSTEM = ISSYSTEM_,
         NOTE = NOTE_,
         FORINSERT = FORINSERT_,
         VALIDATEMESSAGE = VALIDATEMESSAGE_,
         VALIDATELEVEL = VALIDATELEVEL_,
         VALIDATEFILTER = VALIDATEFILTER_,
         ISBUDGET = ISBUDGET_
       WHERE ID = DOCLOCKID$;    
     END IF;  
   ELSE
     INSERT INTO DOCLOCK
       (ISBUDGET,NAME,LOCKMASK,DOCREF,DETAILNUM,RUNPOS,LOCKACTION,USERIGHTS,FORMULA,FORDELETE,ISSYSTEM,NOTE,FORINSERT,VALIDATEMESSAGE,VALIDATELEVEL,VALIDATEFILTER)
     VALUES
       (ISBUDGET_,NAME_,LOCKMASK_,DOCREF_,DETAILNUM_,RUNPOS_,LOCKACTION_,USERIGHTS_,FORMULA_,FORDELETE_,ISSYSTEM_,NOTE_,FORINSERT_,VALIDATEMESSAGE_,VALIDATELEVEL_,VALIDATEFILTER_);
   END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_INSERTFIELD(
  NAME_      VARCHAR2,
  DOCREF_    NUMBER,
  DETAILNUM_ NUMBER,
  FIELDREF_  NUMBER,
  ISBUDGET_ NUMBER)
IS
  NID$ NUMBER(10);
  cnt$ number(10);
BEGIN
  BEGIN
    SELECT ID
    INTO NID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      NID$ := NULL;  
  END;

  IF (NID$ is not null) THEN
    CNT$ := 0;
    SELECT count(ID)
    into cnt$
    FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    
    IF (cnt$ = 0) THEN
      INSERT INTO DOCLOCKFIELDS
        (DOCLOCKREF,FIELDREF,ISSYSTEM)
      VALUES
        (NID$,FIELDREF_,1);
    ELSE
      UPDATE DOCLOCKFIELDS SET
        ISSYSTEM = 1
      WHERE (DOCLOCKREF = NID$) AND (FIELDREF = FIELDREF_) ;
    END IF;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCK_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCK
    WHERE ID = DOCLOCKID$;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE DOCLOCKFIELDS_DELETE(NAME_ VARCHAR2, DOCREF_ NUMBER, DETAILNUM_ NUMBER, CANCHANGEFIELDS_ NUMBER, ISBUDGET_ NUMBER) IS
   DOCLOCKID$ NUMBER(10);
BEGIN
  BEGIN
    SELECT ID
    INTO DOCLOCKID$
    FROM DOCLOCK
    WHERE (DOCREF = DOCREF_) AND (DETAILNUM = DETAILNUM_) AND (NAME = NAME_) AND (ISBUDGET = ISBUDGET_);
  EXCEPTION  
    WHEN NO_DATA_FOUND THEN
      DOCLOCKID$ := NULL;
  END;  

  IF (DOCLOCKID$ is not null) THEN
    DELETE FROM DOCLOCKFIELDS
    WHERE (DOCLOCKREF = DOCLOCKID$) AND ((ISSYSTEM = 1) OR ((ISSYSTEM = 0) AND (CANCHANGEFIELDS_ = 0) ));
  END IF;
END;
/

-- 
CALL DOCLOCK_IMPORT('    ',0,202,1,0,11,0,'([20211096]=0) ((32,45,3) between 0 and 2)',0,3,'         ,    "() "',0,'    .      ,    "() "',null,'(((32,45,3) = 0)   ([980410006] like "?00") 
   (([980410006] like "??0")  (".KVR[CODE].{COUNTNOTNULL(CODE)}",
  (''CODE like "''+ [980410006] div 1 +''_"''))>1))
 (((32,45,3) = 1)  ([980410006] like "??0")   ([980410006] like "?00")) 
 (((32,45,3) = 2)  ([980410006] like "?00")  ([980410006] <> "000"))',1) ;

CALL DOCLOCKFIELDS_DELETE('    ', 202, 1, 0, 1) ;

--  ""
CALL DOCLOCKFIELDS_INSERTFIELD('    ',202,1,20211021,1) ;

CALL DOCLOCK_IMPORT('  ',0,5201,0,0,10,0,'(([520110052] = 4)    (("_._",[520110033])   ("_._",[520110033])   ("_.",[520110033])))   (([520110052] = 3)    (("_.",[520110033])  ("_.",[520110033])   ))   (([520110052] = 0)  ([520110052] = 1)  ([520110052] = 2))',0,3,'',0,'       ',0,'',1) ;

CALL DOCLOCKFIELDS_DELETE('  ', 5201, 0, 0, 1) ;

--  " . "
CALL DOCLOCKFIELDS_INSERTFIELD('  ',5201,0,520110052,1) ;

DROP PROCEDURE DOCLOCK_IMPORT      
/

DROP PROCEDURE DocLockFields_InsertField
/

DROP PROCEDURE DOCLOCK_DELETE
/

DROP PROCEDURE DOCLOCKFIELDS_DELETE
/

CREATE OR REPLACE PROCEDURE LINKTYPE_DELETE(
  NAME_         VARCHAR2,
  TEMPLATECLS_  NUMBER,
  PARENTDOCCLS_ NUMBER,
  CHILDDOCCLS_  NUMBER) IS
BEGIN
  FOR tab_rec in (SELECT id FROM LINKTYPE LT
  WHERE (((NAME_ <> '') or (NAME_ is not null)) and (LT.NAME = NAME_)) or 
    (((NAME_ = '') or (NAME_ is null)) and (LT.TEMPLATECLS = TEMPLATECLS_ AND LT.PARENTDOCCLS = PARENTDOCCLS_ AND LT.CHILDDOCCLS = CHILDDOCCLS_)))    
  LOOP
    UPDATE STATE_JUMPCONTROL SET
      REFERENCEREF = NULL
    WHERE REFERENCEREF = tab_rec.id;
    DELETE FROM REPLACEMENTCLSDETAIL WHERE LINKID IN (SELECT ID FROM LINKRECORDS
      WHERE LINKTYPEREF = tab_rec.id);
    DELETE FROM LINKRECORDS
      WHERE LINKTYPEREF = tab_rec.id;
    DELETE FROM LINKTYPE LT
      WHERE LT.ID = tab_rec.id;
  END LOOP;     
END;
/

CREATE OR REPLACE PROCEDURE LINKTYPE_IMPORT(
   ID_                    NUMBER,
   NAME_                  VARCHAR2,
   TEMPLATECLS_           NUMBER,
   PARENTDOCCLS_          NUMBER,
   CHILDDOCCLS_           NUMBER,
   LINKCOMMENT_           VARCHAR2,
   BLOCKPARENT_           NUMBER,
   BLOCKCHILD_            NUMBER,
   CANDELBLOCKPARENT_     NUMBER,
   CANDELBLOCKCHILD_      NUMBER,
   PARENTPICTURETYPE_     NUMBER,
   PARENTPICTURENAME_     VARCHAR2,
   CHILDPICTURETYPE_      NUMBER,
   CHILDPICTURENAME_      VARCHAR2,
   PICTURECOLLECTIONNAME_ VARCHAR2,
   URMUSE_                NUMBER,
   DELMACROSNAME_         VARCHAR2,
   NEEDDELCHILD_          NUMBER,
   LINKKIND_              NUMBER
) IS
   CNT$ NUMBER(10);
BEGIN
   /*          ,     */
   /*  ,   , ,  ,     */
   IF (
   ((TEMPLATECLS_ is not null)and(TEMPLATECLS_<>0))or(Name_ is not null))   
   THEN
     FOR tab_rec in(SELECT id FROM LINKTYPE LT WHERE 
                 (id<>ID_)      
         and(((TEMPLATECLS_ is not null)and(TEMPLATECLS_<>0)and(LT.TEMPLATECLS = TEMPLATECLS_)
         and (LT.PARENTDOCCLS = PARENTDOCCLS_) and (LT.CHILDDOCCLS = CHILDDOCCLS_))
         or((Name_ is not null)and(lt.Name=Name_))))
     LOOP
        /*             */    
        DELETE FROM LINKRECORDS WHERE LINKTYPEREF = -10;  
        DELETE FROM TB_LINKTYPE WHERE ID = -10;
        DELETE FROM DOCUMENTCLS WHERE ID = -10;
        DELETE FROM DOCUMENTTYPES WHERE ID = -10;
        INSERT INTO DOCUMENTTYPES(ID, PROGINDEX) VALUES(-10, -10);
        INSERT INTO DOCUMENTCLS(ID, DOCTYPE, TABLENAME, TABLENAMEURM, PRIMARYKEYNAME, PRIMARYKEYNAMEURM)
           VALUES(-10, -10, ' ', ' ', ' ', ' ');
        INSERT INTO LINKTYPE(ID, PARENTDOCCLS, CHILDDOCCLS, NAME) VALUES(-10, -10, -10, ' ');
        UPDATE STATE_JUMPCONTROL SET
           REFERENCEREF = -10
        WHERE
           REFERENCEREF = tab_rec.id;
        UPDATE LINKRECORDS SET
           LINKTYPEREF = -10
        WHERE
           LINKTYPEREF = tab_rec.id;
        DELETE FROM TB_LINKTYPE WHERE ID = tab_rec.Id;
     END LOOP;
   end if;
   /*      */ 
   SELECT count(*) into CNT$
      FROM LINKTYPE LT WHERE LT.ID = ID_;
   IF (CNT$ = 0)    
   THEN
      INSERT INTO LINKTYPE
       (ID,NAME,TEMPLATECLS,PARENTDOCCLS, CHILDDOCCLS, LINKCOMMENT, BLOCKPARENT,BLOCKCHILD,CANDELBLOCKPARENT,
        CANDELBLOCKCHILD, PARENTPICTURETYPE,PARENTPICTURENAME,CHILDPICTURETYPE,CHILDPICTURENAME,
        PICTURECOLLECTIONNAME,URMUSE,DELMACROSNAME,NEEDDELCHILD,LINKKIND)
      VALUES
       (ID_,NAME_,TEMPLATECLS_, PARENTDOCCLS_, CHILDDOCCLS_, LINKCOMMENT_, BLOCKPARENT_,BLOCKCHILD_,CANDELBLOCKPARENT_,
        CANDELBLOCKCHILD_, PARENTPICTURETYPE_,PARENTPICTURENAME_,CHILDPICTURETYPE_,CHILDPICTURENAME_,
        PICTURECOLLECTIONNAME_,URMUSE_,DELMACROSNAME_,NEEDDELCHILD_,LINKKIND_);
   ELSE
      UPDATE LINKTYPE SET
         NAME = NAME_,
         TEMPLATECLS = TEMPLATECLS_,
         PARENTDOCCLS = PARENTDOCCLS_,
         CHILDDOCCLS = CHILDDOCCLS_,
         LINKCOMMENT = LINKCOMMENT_,
         BLOCKPARENT = BLOCKPARENT_,
         BLOCKCHILD = BLOCKCHILD_,
         CANDELBLOCKPARENT = CANDELBLOCKPARENT_,
         CANDELBLOCKCHILD = CANDELBLOCKCHILD_,
         PARENTPICTURETYPE = PARENTPICTURETYPE_,
         PARENTPICTURENAME = PARENTPICTURENAME_,
         CHILDPICTURETYPE = CHILDPICTURETYPE_,
         CHILDPICTURENAME = CHILDPICTURENAME_,
         PICTURECOLLECTIONNAME = PICTURECOLLECTIONNAME_,
         URMUSE = URMUSE_,
         DELMACROSNAME = DELMACROSNAME_,
         NEEDDELCHILD = NEEDDELCHILD_,
         LINKKIND = LINKKIND_
      WHERE ID = ID_;
   END IF;      
   
   /*      ,      */
   UPDATE STATE_JUMPCONTROL SET
     REFERENCEREF = ID_
   WHERE
     REFERENCEREF = -10;
   UPDATE LINKRECORDS SET
      LINKTYPEREF = ID_
   WHERE
      LINKTYPEREF = -10;
   /*   */  
   DELETE FROM TB_LINKTYPE WHERE ID = -10;
   DELETE FROM DOCUMENTCLS WHERE ID = -10;
   DELETE FROM DOCUMENTTYPES WHERE ID = -10;
END;
/

--  
CALL LINKTYPE_IMPORT(520300800,' - ',null,520101,32201,'        ',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(520300900,' - ',null,520100,32200,'       ',0,0,0,0,1,'',1,'','',1,'',0,0) ;

CALL LINKTYPE_IMPORT(34903100,'->',null,30700,490300,'     ',0,0,1,1,2,'_',1,'','1616',0,'',0,3) ;

CALL LINKTYPE_IMPORT(494900200,'->',null,490300,490300,'     ',0,0,1,1,2,'_',1,'','1616',0,'',0,3) ;

DROP PROCEDURE LINKTYPE_DELETE
/

DROP PROCEDURE LINKTYPE_IMPORT
/

CREATE OR REPLACE PROCEDURE STATICLINK_DELETE(ID_ NUMBER) IS
BEGIN
  DELETE FROM STATICLINKS SL
  WHERE SL.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE STATICLINK_IMPORT(
  ID_             NUMBER,
  NAME_           VARCHAR2,
  PARENTFIELDREF_ NUMBER,
  CHILDFIELDREF_  NUMBER,
  LINKKIND_      NUMBER,
  ParentDelAction_ NUMBER
) IS
  FINDID$ NUMBER;
  FINDNEWID$ NUMBER;
  IDExists$ NUMBER;
BEGIN
  /*     ID,    CHILDFIELDREF,PARENTFIELDREF. 
   ,     ,    ID.       ID  , 
   (  )     id ,      */
  BEGIN
    SELECT
      SL.ID
    INTO FINDID$
    FROM 
      STATICLINKS SL
    WHERE (SL.CHILDFIELDREF = CHILDFIELDREF_) AND (SL.PARENTFIELDREF = PARENTFIELDREF_) AND (SL.ID <> ID_);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      FINDID$ := NULL;
  END;
  
  IF (FINDID$ IS NOT NULL) THEN
  /*   ID         */

    SELECT COUNT (ID)
      INTO IDExists$
      FROM STATE_JUMPCONTROL
    WHERE (STATICLINKREF = FINDID$);

    IF (IDExists$ > 0) THEN

      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM 
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
 
      IF (FINDNEWID$ IS NULL) THEN
        INSERT INTO STATICLINKS
         (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
        VALUES
          (ID_,NAME_,CHILDFIELDREF_,PARENTFIELDREF_,1,ParentDelAction_);
      END IF;        
      UPDATE STATE_JUMPCONTROL
        SET STATICLINKREF = ID_
      WHERE (STATICLINKREF = FINDID$);

      DELETE FROM STATICLINKS  
      WHERE ID=FINDID$;
    ELSE   
      BEGIN
        SELECT
          SL.ID
        INTO FINDNEWID$
        FROM
          STATICLINKS SL
        WHERE (SL.ID = ID_);
      EXCEPTION
        WHEN NO_DATA_FOUND THEN
          FINDNEWID$ := NULL;
      END;
      IF (FINDNEWID$ IS NULL) THEN
        UPDATE STATICLINKS
        SET ID=ID_
        WHERE ID=FINDID$;
      ELSE
        DELETE FROM STATICLINKS
        WHERE ID=FINDID$;
      END IF;
    END IF;
      
  END IF; /*  id  */
  
  /*       ( ), 
   ,            CHILDFIELDREF.
   ,        1( )*/
  IF (LINKKIND_=0) THEN
    UPDATE STATICLINKS
    SET LINKKIND=1  
    WHERE (CHILDFIELDREF = CHILDFIELDREF_) AND (ID <> ID_) AND (LINKKIND=0);
  END IF;    
  
  /*        id.  ,   .  ,   */
  BEGIN
    SELECT SL.ID
      INTO FINDID$
      FROM
        STATICLINKS SL
      WHERE
        (SL.ID = ID_);
  EXCEPTION
      WHEN NO_DATA_FOUND THEN
        FINDID$ := NULL;
  END;
  IF (FINDID$ IS NOT NULL) THEN
    UPDATE STATICLINKS SET
      NAME           = NAME_,
      PARENTFIELDREF = PARENTFIELDREF_,
      CHILDFIELDREF  = CHILDFIELDREF_,
      LINKKIND       = LINKKIND_,
      ParentDelAction = ParentDelAction_
      WHERE ID = ID_;
  ELSE
    INSERT INTO STATICLINKS
     (ID,NAME,PARENTFIELDREF,CHILDFIELDREF,LINKKIND,ParentDelAction)
    VALUES
      (ID_,NAME_,PARENTFIELDREF_,CHILDFIELDREF_,LINKKIND_,ParentDelAction_);
  END IF;      

END;
/

--  
CALL STATICLINK_DELETE(999900400) ;

CALL STATICLINK_IMPORT(962501100,'.EXECUTERINN->.ID',960110033,250410049,0,0) ;

CALL STATICLINK_IMPORT(962500200,'.EXECUTER_REF->.ID',960110033,250410089,0,0) ;

DROP PROCEDURE STATICLINK_DELETE
/

DROP PROCEDURE STATICLINK_IMPORT
/

CREATE OR REPLACE PROCEDURE FILTERS_DELETE(ID_ NUMBER) IS
BEGIN
  DELETE FROM STATE_JUMPCONTROL
  WHERE STATE_JUMPCONTROL.FILTERCODE = ID_;
  UPDATE STATE_ACTIONJUMPS SAJ
  SET SAJ.FILTERCODE = NULL, SAJ.OPTIONS = NULL
  WHERE SAJ.FILTERCODE = ID_;
  DELETE FROM State_Filter SF
  WHERE SF.ID = ID_;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORT(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValue_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValue,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValue_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValue = FilterValue_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE FILTERS_IMPORTURM(
  ID_ NUMBER,
  Name_ VARCHAR2,
  Note_ VARCHAR2,
  FilterValueURM_ VARCHAR2,
  FilterFormat_ NUMBER,
  FilterActive_ NUMBER,
  IsBudget_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM State_Filter
  WHERE (ID = ID_);
  IF (IDExists$ = 0) THEN
  INSERT INTO State_Filter
    (ID,NAME,Note,FilterValueURM,FilterFormat,FilterActive,IsBudget)
  VALUES
    (ID_,NAME_,Note_,FilterValueURM_,FilterFormat_,FilterActive_,IsBudget_);
  ELSE
    UPDATE State_Filter SET
      NAME = NAME_,
      Note = Note_,
      FilterValueURM = FilterValueURM_,
      FilterFormat = FilterFormat_,
      FilterActive = FilterActive_,
      IsBudget = IsBudget_
    WHERE ID = ID_;
  END IF;
END;
/

-- 
DROP PROCEDURE FILTERS_DELETE
/

DROP PROCEDURE FILTERS_IMPORT
/

DROP PROCEDURE FILTERS_IMPORTURM
/

CREATE OR REPLACE PROCEDURE STATUSICONS_IMPORT(
  ID_ NUMBER,
  NOTE_ VARCHAR2,
  DOCREF_ NUMBER,
  DETAILNUM_ NUMBER,
  ICONNAME_ VARCHAR2,
  ISSYSTEM_ NUMBER,
  ICONPOS_ NUMBER,
  RUNPOS_ NUMBER,
  RESERVEPOS_ NUMBER,
  ICONHINT_ VARCHAR2,
  ICONKIND_ NUMBER,
  LOCKMASK_ NUMBER,
  FORMULA_ VARCHAR2,
  ISBUDGET_ NUMBER
) IS
  IDExists$ NUMBER (10);
BEGIN
  SELECT COUNT(ID)
  INTO IDExists$
  FROM STATUSICONS
  WHERE (ID = ID_);
  IF (IDExists$ <> 0) THEN
    UPDATE STATUSICONS SET
      NOTE = NOTE_,
      DOCREF = DOCREF_,
      DETAILNUM = DETAILNUM_,
      ICONNAME = ICONNAME_,
      ISSYSTEM = ISSYSTEM_,
      ICONPOS = ICONPOS_,
      RUNPOS = RUNPOS_,
      RESERVEPOS = RESERVEPOS_,
      ICONHINT = ICONHINT_,
      ICONKIND = ICONKIND_,
      LOCKMASK = LOCKMASK_,
      ISBUDGET = ISBUDGET_,
      FORMULA = FORMULA_
    WHERE ID = ID_;
  ELSE
    INSERT INTO STATUSICONS
      (ISBUDGET, ID, NOTE, DOCREF, DETAILNUM, ICONNAME, ISSYSTEM, ICONPOS, RUNPOS, RESERVEPOS, ICONHINT, ICONKIND, LOCKMASK, FORMULA)
    VALUES
      (ISBUDGET_, ID_, NOTE_, DOCREF_, DETAILNUM_, ICONNAME_, ISSYSTEM_, ICONPOS_, RUNPOS_, RESERVEPOS_, ICONHINT_, ICONKIND_, LOCKMASK_, FORMULA_);
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE STATUSICONS_DELETE(
  ID_ NUMBER
) IS
BEGIN
  DELETE FROM STATUSICONS SI
  WHERE SI.ID = ID_;
END;
/

--  
DROP PROCEDURE STATUSICONS_IMPORT
/

DROP PROCEDURE STATUSICONS_DELETE
/


CREATE OR REPLACE PROCEDURE ENUMS_IMPORT(NAME_ VARCHAR2,FACIALACCCLS_ NUMBER) IS
  IDEXISTS$ NUMBER;
BEGIN
  SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMS WHERE NAME = NAME_;
  IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMS E1
      WHERE (E1.NAME = NAME_) AND (E1.ID > (SELECT MIN(E2.ID) FROM ENUMS E2 WHERE E2.NAME = NAME_));
  END IF;
  IF (IDEXISTS$ > 0) THEN
    UPDATE ENUMS SET
      FACIALACCCLS = FACIALACCCLS_,
      ISSYSTEM = 1
    WHERE NAME = NAME_;
  ELSE
    INSERT INTO ENUMS
      (NAME,FACIALACCCLS,ISSYSTEM)    
    VALUES
      (NAME_,FACIALACCCLS_,1);
  END IF;    
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_IMPORT(ENUMNAME_ VARCHAR2,NAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
  IDEXISTS$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
      IDENUM$ := NULL;
  END;  
  IF (IDENUM$ IS NOT NULL) THEN
    SELECT COUNT(ID) INTO IDEXISTS$ FROM ENUMVALUES WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    IF (IDEXISTS$ > 1) THEN
      DELETE FROM ENUMVALUES EV1
      WHERE (EV1.ENUMREF = IDENUM$) AND (EV1.VAL = VAL_) AND
        (EV1.ID > (SELECT MIN(EV2.ID) FROM ENUMVALUES EV2 WHERE EV2.ENUMREF = IDENUM$ AND EV2.VAL = VAL_));
    END IF;
    IF (IDEXISTS$ > 0) THEN
      UPDATE ENUMVALUES SET
        NAME = NAME_
      WHERE ENUMREF = IDENUM$ AND VAL = VAL_;
    ELSE
      INSERT INTO ENUMVALUES
        (VAL,NAME,ENUMREF)  
      VALUES
        (VAL_,NAME_,IDENUM$);
    END IF;    
  END IF;
END;
/

CREATE OR REPLACE PROCEDURE ENUMS_DELETE(NAME_ VARCHAR2) IS
BEGIN
  DELETE FROM ENUMS WHERE NAME = NAME_;
END;
/

CREATE OR REPLACE PROCEDURE ENUMVALUES_DELETE(ENUMNAME_ VARCHAR2,VAL_ NUMBER) IS
  IDENUM$ NUMBER;
BEGIN
  BEGIN
    SELECT ID INTO IDENUM$ FROM ENUMS WHERE NAME = ENUMNAME_;
  EXCEPTION
     WHEN NO_DATA_FOUND THEN
       IDENUM$ := NULL;  
  END;
  IF (IDENUM$ IS NOT NULL) THEN
    DELETE FROM ENUMVALUES WHERE (VAL = VAL_) AND (ENUMREF = IDENUM$);
  END IF;  
END;
/

-- 
DROP PROCEDURE ENUMS_IMPORT
/

DROP PROCEDURE ENUMVALUES_IMPORT
/

DROP PROCEDURE ENUMS_DELETE
/

DROP PROCEDURE ENUMVALUES_DELETE
/

--      
INSERT INTO DFUCHANGELOG (VersionID, BEGINUPDATECODE, ENDUPDATECODE, LASTUPDATEDFU, ISBUDGET, INCLUDEDEL, INCLUDEBLOCKS, INCLUDEDOCS, SCRIPTCREATOR, SCRIPTCREATEDATE, NOTE) VALUES (1173, 111000, 111000, TO_DATE('26.01.2016 10:21:45', 'DD.MM.YYYY HH24:MI:SS'), 1, 1, ',    ,  , ,  , ,  , , ', '00.00, 01.01, 02.00, 02.01, 02.02, 02.03, 02.04, 02.05, 02.06, 02.07, 02.08, 02.09, 02.10, 02.11, 02.12, 03.00, 03.01, 03.02, 03.03, 03.04, 03.05, 03.06, 03.07, 03.08, 03.11, 03.12, 03.14, 03.15, 03.16, 03.22, 03.23, 03.24, 04.01, 05.01, 07.01, 07.02, 07.03, 08.01, 08.02, 08.03, 08.04, 09.00, 09.01, 09.02, 09.03, 09.05, 09.06, 09.07, 12.01, 15.01, 16.01, 16.02, 17.01, 17.02, 18.05, 18.07, 18.09, 18.10, 18.12, 18.13, 18.14, 18.15, 18.16, 19.00, 19.01, 19.02, 19.03, 19.06, 22.00, 22.01, 25.01, 25.02, 25.03, 25.04, 28.01, 28.02, 30.01, 30.03, 30.04, 30.06, 36.10, 37.01, 39.01, 44.01, 44.03, 48.01, 49.01, 49.02, 49.03, 51.01, 52.01, 53.01, 53.02, 55.01, 55.02, 55.03, 96.01, 96.02, 96.03, 96.04, 97.01, 97.02, 98.02, 98.03, 98.04, 98.05, 98.06, 98.08, 98.09, 98.10, 98.11, 98.12, 98.13, 98.14, 98.15, 98.16, 98.17, 98.18, 98.20, 98.21, 98.22, 98.23, 98.26, 98.27, 98.28, 98.29, 98.34, 98.35, 98.41, 98.42, 98.43, 98.44, 98.45, 98.46, 98.47, 98.48, 98.49, 98.50, 98.51, 98.52, 98.53, 98.54, 98.57, 98.58, 98.59, 98.60, 98.61, 98.62, 98.63, 98.64, 98.65, 98.67, 98.68, 98.69, 98.70, 98.71, 98.72, 98.78, 98.79, 98.80, 98.81, 98.82, 98.83, 98.84, 98.85, 98.86, 98.87, 98.88, 98.89, 98.90, 98.91, 98.92, 98.94, 98.95, 98.99, 99.03, 99.04, 99.05, 99.08, 99.12, 99.13, 99.14, 99.15, 99.16, 99.17, 99.18, 99.19, 99.20, 99.21, 99.22, 99.23, 99.24, 99.25, 99.26, 99.27, 99.28, 99.29, 99.30', 'SHIBAEV8/shibaev', TO_DATE('27.01.2016 11:0:6', 'DD.MM.YYYY HH24:MI:SS'), '') ;

COMMIT WORK
/



-- #########################################################
-- #########################################################
-- DBVersion.sql
-- #########################################################
-- #########################################################

INSERT INTO DataBaseVersion(VERSION, Major, Minor, AComment)
  VALUES ('11.10.00', 1110, 00, ' 11.1')
/

COMMIT WORK
/

-- #########################################################
-- #########################################################
-- Index_Fix.sql
-- #########################################################
-- #########################################################

--      INDX
DECLARE
  CURSOR C$ IS
    select INDEX_NAME from DBA_INDEXES
    where OWNER = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      and TABLESPACE_NAME <> 'INDX'
      and INDEX_TYPE LIKE '%NORMAL%';
  CNT$ NUMBER(10);    
BEGIN
  BEGIN
    select count(*) into CNT$ from V$TABLESPACE
    where name = 'INDX';
  EXCEPTION
    WHEN OTHERS THEN
      CNT$ := 1;
  END;
  IF CNT$ = 1 THEN
    FOR R$ IN C$ LOOP
      EXECUTE IMMEDIATE 'ALTER INDEX ' || R$.INDEX_NAME || ' REBUILD TABLESPACE INDX';
    END LOOP;
  END IF;
END;
/

-- #########################################################
-- #########################################################
-- compile_scr.sql
-- #########################################################
-- #########################################################

--      , 
--  -  
--  DBMS_UTILITY.COMPILE_SCHEMA(user, TRUE);

DECLARE
  CURSOR C$ IS
    SELECT 'ALTER ' || object_type || ' ' || owner || '.' || object_name || ' COMPILE' AS str,
      object_type, object_name
    FROM SYS.ALL_OBJECTS
    WHERE owner = SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA')
      AND object_type IN ('VIEW', 'PROCEDURE', 'TRIGGER')
      AND status = 'INVALID'
      AND object_name not like 'BIN$%'
    ORDER BY DECODE(object_type, 'VIEW', 1, 'PROCEDURE', 2, 'TRIGGER', 3), object_name;
  S VARCHAR2(100);
BEGIN
  FOR R$ IN C$ LOOP
    BEGIN
      S := R$.object_type || ' ' || R$.object_name;
      EXECUTE IMMEDIATE R$.str;
    EXCEPTION
      WHEN OTHERS THEN 
        --DBMS_OUTPUT.PUT_LINE(S);
        RAISE_APPLICATION_ERROR(-20000, '    ' || S);
    END;
  END LOOP;
END;
/

-- #########################################################
-- #########################################################
-- dbms_stats_scr.sql
-- #########################################################
-- #########################################################

ALTER SESSION SET NLS_NUMERIC_CHARACTERS='.,'
/

BEGIN
  DBMS_STATS.GATHER_SCHEMA_STATS(
    SYS_CONTEXT ('USERENV', 'CURRENT_SCHEMA'),
    DBMS_STATS.AUTO_SAMPLE_SIZE,
    false,
    'FOR ALL COLUMNS SIZE AUTO',
    cascade=>TRUE
  );
END;
/

exit
